@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
@@ -14,11 +14,9 @@ related to `IDEA <https://idea.cesnet.cz/en/index>`__ events, database searching
 viewing event details and producing event dashboards.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import datetime
 
 import flask
@@ -31,42 +29,44 @@ from mentat.const import tr_
 
 import hawat.const
 import hawat.events
-import vial.const
-import vial.acl
-from vial.app import VialBlueprint
-from vial.view import BaseView, SimpleView, BaseSearchView, ItemShowView
-from vial.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
-from vial.utils import URLParamsBuilder
+import hawat.const
+import hawat.acl
+import hawat.forms
+import hawat.menu
+from hawat.base import HawatBlueprint
+from hawat.view import BaseView, SimpleView, BaseSearchView, ItemShowView
+from hawat.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
+from hawat.utils import URLParamsBuilder
 from hawat.base import PsycopgMixin
 from hawat.blueprints.events.forms import SimpleEventSearchForm, EventDashboardForm
 
-
 BLUEPRINT_NAME = 'events'
 """Name of the blueprint as module global constant."""
 
 
-def _get_search_form(request_args = None):
+def _get_search_form(request_args=None):
     choices = hawat.events.get_event_form_choices()
 
     form = SimpleEventSearchForm(
         request_args,
-        meta = {'csrf': False},
-        choices_source_types    = choices['source_types'],
-        choices_target_types    = choices['target_types'],
-        choices_host_types      = choices['host_types'],
-        choices_detectors       = choices['detectors'],
-        choices_detector_types  = choices['detector_types'],
-        choices_categories      = choices['categories'],
-        choices_severities      = choices['severities'],
-        choices_classes         = choices['classes'],
-        choices_protocols       = choices['protocols'],
-        choices_inspection_errs = choices['inspection_errs'],
+        meta={'csrf': False},
+        choices_source_types=choices['source_types'],
+        choices_target_types=choices['target_types'],
+        choices_host_types=choices['host_types'],
+        choices_detectors=choices['detectors'],
+        choices_detector_types=choices['detector_types'],
+        choices_categories=choices['categories'],
+        choices_severities=choices['severities'],
+        choices_classes=choices['classes'],
+        choices_protocols=choices['protocols'],
+        choices_inspection_errs=choices['inspection_errs'],
     )
 
     # In case no time bounds were set adjust them manually.
-    if request_args and not ('dt_from' in request_args or 'dt_to' in request_args or 'st_from' in request_args or 'st_to' in request_args):
-        form.dt_from.process_data(vial.forms.default_dt_with_delta())
-        form.dt_to.process_data(vial.forms.default_dt())
+    if request_args and not (
+            'dt_from' in request_args or 'dt_to' in request_args or 'st_from' in request_args or 'st_to' in request_args):
+        form.dt_from.process_data(hawat.forms.default_dt_with_delta())
+        form.dt_to.process_data(hawat.forms.default_dt())
 
     return form
 
@@ -99,7 +99,7 @@ class AbstractSearchView(PsycopgMixin, BaseSearchView):  # pylint: disable=local
 
     def do_before_response(self, **kwargs):
         self.response_context.update(
-            quicksearch_list = self.get_quicksearch_by_time()
+            quicksearch_list=self.get_quicksearch_by_time()
         )
 
 
@@ -121,33 +121,33 @@ class SearchView(HTMLMixin, AbstractSearchView):  # pylint: disable=locally-disa
 
     @classmethod
     def get_breadcrumbs_menu(cls):
-        breadcrumbs_menu = vial.menu.Menu()
+        breadcrumbs_menu = hawat.menu.Menu()
         breadcrumbs_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['ENDPOINT_HOME']
+            endpoint=flask.current_app.config['ENDPOINT_HOME']
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
             'search',
-            endpoint = '{}.search'.format(cls.module_name)
+            endpoint='{}.search'.format(cls.module_name)
         )
         return breadcrumbs_menu
 
     @classmethod
     def get_context_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
-            endpoint = 'events.show',
-            hidetitle = True
+            endpoint='events.show',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'download',
-            endpoint = 'events.download',
-            hidetitle = True
+            endpoint='events.download',
+            hidetitle=True
         )
         return action_menu
 
@@ -157,7 +157,7 @@ class APISearchView(AJAXMixin, AbstractSearchView):  # pylint: disable=locally-d
     View responsible for searching the `IDEA <https://idea.cesnet.cz/en/index>`__
     event database and presenting the results in the form of JSON document.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     @classmethod
     def get_view_name(cls):
@@ -183,7 +183,7 @@ class AbstractShowView(PsycopgMixin, ItemShowView):  # pylint: disable=locally-d
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'View details of event &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].get_id())
+            item=flask.escape(kwargs['item'].get_id())
         )
 
 
@@ -198,11 +198,11 @@ class ShowView(HTMLMixin, AbstractShowView):  # pylint: disable=locally-disabled
 
     @classmethod
     def get_action_menu(cls):  # pylint: disable=locally-disabled,unused-argument
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'download',
-            endpoint = 'events.download'
+            endpoint='events.download'
         )
         return action_menu
 
@@ -212,7 +212,7 @@ class APIShowView(AJAXMixin, AbstractShowView):  # pylint: disable=locally-disab
     Detailed `IDEA <https://idea.cesnet.cz/en/index>`__ event view that presents
     the result as HTML page.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     @classmethod
     def get_view_name(cls):
@@ -239,7 +239,7 @@ class DownloadView(PsycopgMixin, BaseView):
     def get_view_url(cls, **kwargs):
         return flask.url_for(
             cls.get_view_endpoint(),
-            item_id = kwargs['item'].get_id()
+            item_id=kwargs['item'].get_id()
         )
 
     @classmethod
@@ -250,10 +250,10 @@ class DownloadView(PsycopgMixin, BaseView):
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Download event &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].get_id())
+            item=flask.escape(kwargs['item'].get_id())
         )
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def dispatch_request(self, item_id):  # pylint: disable=locally-disabled,arguments-differ
         """
@@ -273,7 +273,7 @@ class DownloadView(PsycopgMixin, BaseView):
         )
 
         response = flask.make_response(
-            item.to_json(indent = 4, sort_keys = True)
+            item.to_json(indent=4, sort_keys=True)
         )
         response.mimetype = 'application/json'
         response.headers['Content-Disposition'] = 'attachment; filename={}.idea.json'.format(item_id)
@@ -303,7 +303,7 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
     def get_view_template(cls):
         return '{}/{}.html'.format(cls.module_name, cls.get_view_name())
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
@@ -311,7 +311,7 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
 
     @staticmethod
     def get_search_form(request_args):
-        return EventDashboardForm(request_args, meta = {'csrf': False})
+        return EventDashboardForm(request_args, meta={'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
@@ -333,10 +333,10 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
         if items:
             dt_from = self.response_context['form_data'].get('dt_from', None)
             if dt_from:
-                dt_from = dt_from.replace(tzinfo = None)
-            dt_to   = self.response_context['form_data'].get('dt_to', None)
+                dt_from = dt_from.replace(tzinfo=None)
+            dt_to = self.response_context['form_data'].get('dt_to', None)
             if dt_to:
-                dt_to = dt_to.replace(tzinfo = None)
+                dt_to = dt_to.replace(tzinfo=None)
 
             if not dt_from:
                 dt_from = self.dbcolumn_min(self.dbmodel.createtime)
@@ -344,18 +344,18 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
                 dt_to = datetime.datetime.utcnow()
 
             self.response_context.update(
-                statistics = mentat.stats.idea.aggregate_timeline_groups(
+                statistics=mentat.stats.idea.aggregate_timeline_groups(
                     items,
-                    dt_from = dt_from,
-                    dt_to = dt_to,
-                    max_count = flask.current_app.config['HAWAT_CHART_TIMELINE_MAXSTEPS'],
-                    min_step = 300
+                    dt_from=dt_from,
+                    dt_to=dt_to,
+                    max_count=flask.current_app.config['HAWAT_CHART_TIMELINE_MAXSTEPS'],
+                    min_step=300
                 )
             )
 
     def do_before_response(self, **kwargs):
         self.response_context.update(
-            quicksearch_list = self.get_quicksearch_by_time()
+            quicksearch_list=self.get_quicksearch_by_time()
         )
 
 
@@ -376,7 +376,7 @@ class APIDashboardView(AJAXMixin, AbstractDashboardView):  # pylint: disable=loc
     View responsible for presenting overall `IDEA <https://idea.cesnet.cz/en/index>`__
     event statistics dashboard in the form of JSON document.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     @classmethod
     def get_view_name(cls):
@@ -399,7 +399,7 @@ class APIMetadataView(AJAXMixin, SimpleView):
     """
     authentication = True
 
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     @classmethod
     def get_view_name(cls):
@@ -413,10 +413,10 @@ class APIMetadataView(AJAXMixin, SimpleView):
         self.response_context.update(**hawat.events.get_event_enums())
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
-class EventsBlueprint(VialBlueprint):
+class EventsBlueprint(HawatBlueprint):
     """Pluggable module - `IDEA <https://idea.cesnet.cz/en/index>`__ event database (*events*)."""
 
     @classmethod
@@ -427,15 +427,15 @@ class EventsBlueprint(VialBlueprint):
         app.menu_main.add_entry(
             'view',
             'dashboards.{}'.format(BLUEPRINT_NAME),
-            position = 10,
-            view = DashboardView
+            position=10,
+            view=DashboardView
         )
         app.menu_main.add_entry(
             'view',
             BLUEPRINT_NAME,
-            position = 140,
-            view = SearchView,
-            resptitle = True
+            position=140,
+            view=SearchView,
+            resptitle=True
         )
 
         def _get_upb():
@@ -555,31 +555,31 @@ class EventsBlueprint(VialBlueprint):
         )
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 def get_blueprint():
     """
-    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
-    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    Mandatory interface for :py:mod:`hawat.Hawat` and factory function. This function
+    must return a valid instance of :py:class:`hawat.app.HawatBlueprint` or
     :py:class:`flask.Blueprint`.
     """
 
     hbp = EventsBlueprint(
         BLUEPRINT_NAME,
         __name__,
-        template_folder = 'templates',
-        static_folder   = 'static',
-        static_url_path = '/{}/static'.format(BLUEPRINT_NAME)
+        template_folder='templates',
+        static_folder='static',
+        static_url_path='/{}/static'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(SearchView,       '/{}/search'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(ShowView,         '/{}/<item_id>/show'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(DownloadView,     '/{}/<item_id>/download'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(DashboardView,    '/{}/dashboard'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(APISearchView,    '/api/{}/search'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(APIShowView,      '/api/{}/<item_id>/show'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(SearchView, '/{}/search'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(ShowView, '/{}/<item_id>/show'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DownloadView, '/{}/<item_id>/download'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DashboardView, '/{}/dashboard'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(APISearchView, '/api/{}/search'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(APIShowView, '/api/{}/<item_id>/show'.format(BLUEPRINT_NAME))
     hbp.register_view_class(APIDashboardView, '/api/{}/dashboard'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(APIMetadataView,  '/api/{}/metadata'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(APIMetadataView, '/api/{}/metadata'.format(BLUEPRINT_NAME))
 
     return hbp
