@@ -15,14 +15,14 @@ Unit tests for :py:mod:`hawat.blueprints.events`.
 
 import unittest
 
-import vial.const
-import vial.test
-import vial.db
-from vial.test import VialTestCase
+import hawat.const
+import hawat.test
+import hawat.db
+from hawat.test import HawatTestCase
 from hawat.test.runner import TestRunnerMixin
 
 
-class SearchTestCase(TestRunnerMixin, VialTestCase):
+class SearchTestCase(TestRunnerMixin, HawatTestCase):
     """
     Class for testing ``events.search`` endpoint.
     """
@@ -51,28 +51,28 @@ class SearchTestCase(TestRunnerMixin, VialTestCase):
         """Test access as anonymous user."""
         self._attempt_fail_redirect()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_02_as_user(self):
         """Test access as user ``user``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_03_as_developer(self):
         """Test access as user ``developer``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_04_as_maintainer(self):
         """Test access as user ``maintainer``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_05_as_admin(self):
         """Test access as user ``admin``."""
         self._attempt_succeed()
 
 
-class DashboardTestCase(TestRunnerMixin, VialTestCase):
+class DashboardTestCase(TestRunnerMixin, HawatTestCase):
     """
     Class for testing ``events.dashboard`` endpoint.
     """
@@ -101,22 +101,22 @@ class DashboardTestCase(TestRunnerMixin, VialTestCase):
         """Test access as anonymous user."""
         self._attempt_fail_redirect()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_02_as_user(self):
         """Test access as user ``user``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_03_as_developer(self):
         """Test access as user ``developer``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_04_as_maintainer(self):
         """Test access as user ``maintainer``."""
         self._attempt_succeed()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_05_as_admin(self):
         """Test access as user ``admin``."""
         self._attempt_succeed()
