@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
@@ -19,13 +19,12 @@ features include:
 * deleting existing reporting filters
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import sys
 import traceback
+import markupsafe
 
 import flask
 import flask_login
@@ -45,22 +44,23 @@ from mentat.const import REPORTING_FILTER_BASIC
 from mentat.datatype.sqldb import FilterModel, GroupModel, ItemChangeLogModel
 from mentat.idea.internal import Idea, IDEAFilterCompiler
 
-import vial.const
-import vial.db
-from vial.app import VialBlueprint
-from vial.view import RenderableView, ItemListView, ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView, ItemDeleteView, ItemEnableView, ItemDisableView
-from vial.view.mixin import HTMLMixin, SQLAlchemyMixin
+import hawat.const
+import hawat.db
+import hawat.acl
+import hawat.menu
+from hawat.base import HawatBlueprint
+from hawat.view import RenderableView, ItemListView, ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView, \
+    ItemDeleteView, ItemEnableView, ItemDisableView
+from hawat.view.mixin import HTMLMixin, SQLAlchemyMixin
 import hawat.events
 from hawat.blueprints.filters.forms import BaseFilterForm, AdminFilterForm, PlaygroundFilterForm, FilterSearchForm
 
-
 _PARSER = PynspectFilterParser()
 _PARSER.build()
 
 _COMPILER = IDEAFilterCompiler()
 _FILTER = DataObjectFilter()
 
-
 BLUEPRINT_NAME = 'filters'
 """Name of the blueprint as module global constant."""
 
@@ -81,6 +81,7 @@ def process_rule(item):
         if item.ips:
             ip4s = []
             ip6s = []
+            rule_ip4 = rule_ip6 = None
             for ipa in item.ips:
                 ipobj = ipranges.from_str(ipa)
                 if isinstance(ipobj, (ipranges.IP4, ipranges.IP4Range, ipranges.IP4Net)):
@@ -88,9 +89,13 @@ def process_rule(item):
                 else:
                     ip6s.append(ipa)
             if ip4s:
-                rules.append('Source.IP4 IN ["{}"]'.format('","'.join(ip4s)))
+                rule_ip4 = 'Source.IP4 IN ["{}"]'.format('","'.join(ip4s))
             if ip6s:
-                rules.append('Source.IP6 IN ["{}"]'.format('","'.join(ip6s)))
+                rule_ip6 = 'Source.IP6 IN ["{}"]'.format('","'.join(ip6s))
+            if rule_ip4 and rule_ip6:
+                rules.append('({} OR {})'.format(rule_ip4, rule_ip6))
+            elif rule_ip4 or rule_ip6:
+                rules.append(rule_ip4 if rule_ip4 else rule_ip6)
 
         item.filter = ' AND '.join(rules)
 
@@ -103,6 +108,7 @@ def to_tree(rule):
         return _PARSER.parse(rule)
     return None
 
+
 def tree_compile(rule_tree):
     """
     Compile given filtering rule tree.
@@ -111,6 +117,7 @@ def tree_compile(rule_tree):
         return _COMPILER.compile(rule_tree)
     return None
 
+
 def tree_html(rule_tree):
     """
     Render given rule object tree to HTML formatted content.
@@ -119,6 +126,7 @@ def tree_html(rule_tree):
         return rule_tree.traverse(pynspect.traversers.HTMLTreeTraverser())
     return None
 
+
 def tree_check(rule_tree, data):
     """
     Check given event against given rule tree.
@@ -134,13 +142,13 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     authentication = True
 
-    authorization = [vial.acl.PERMISSION_POWER]
+    authorization = [hawat.acl.PERMISSION_POWER]
 
     @classmethod
     def get_view_title(cls, **kwargs):
         return lazy_gettext('Filter management')
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
@@ -148,53 +156,53 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     @classmethod
     def get_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'create',
-            endpoint = 'filters.create',
-            resptitle = True
+            endpoint='filters.create',
+            resptitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'playground',
-            endpoint = 'filters.playground',
-            resptitle = True
+            endpoint='filters.playground',
+            resptitle=True
         )
         return action_menu
 
     @classmethod
     def get_context_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
-            endpoint = 'filters.show',
-            hidetitle = True
+            endpoint='filters.show',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'update',
-            endpoint = 'filters.update',
-            hidetitle = True
+            endpoint='filters.update',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'disable',
-            endpoint = 'filters.disable',
-            hidetitle = True
+            endpoint='filters.disable',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'enable',
-            endpoint = 'filters.enable',
-            hidetitle = True
+            endpoint='filters.enable',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'delete',
-            endpoint = 'filters.delete',
-            hidetitle = True
+            endpoint='filters.delete',
+            hidetitle=True
         )
         return action_menu
 
@@ -206,14 +214,14 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
         """
         return FilterSearchForm(
             request_args,
-            meta = {'csrf': False}
+            meta={'csrf': False}
         )
 
     @staticmethod
     def build_query(query, model, form_args):
         # Adjust query based on text search string.
         if 'search' in form_args and form_args['search']:
-            query = query\
+            query = query \
                 .filter(
                     or_(
                         model.name.like('%{}%'.format(form_args['search'])),
@@ -238,7 +246,7 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
             query = query.filter(model.type == form_args['type'])
         # Adjust query based on user membership selection.
         if 'group' in form_args and form_args['group']:
-            query = query\
+            query = query \
                 .filter(model.group_id == form_args['group'].id)
         if 'sortby' in form_args and form_args['sortby']:
             sortmap = {
@@ -267,7 +275,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'View details of reporting filter &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].name)
+            item=markupsafe.escape(kwargs['item'].name)
         )
 
     @classmethod
@@ -281,38 +289,38 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_mm = flask_principal.Permission(
-            vial.acl.MembershipNeed(kwargs['item'].group.id),
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.MembershipNeed(kwargs['item'].group.id),
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_mm.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_mm.can()
 
     @classmethod
     def get_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'update',
-            endpoint = 'filters.update',
+            endpoint='filters.update',
         )
         action_menu.add_entry(
             'endpoint',
             'disable',
-            endpoint = 'filters.disable',
+            endpoint='filters.disable',
         )
         action_menu.add_entry(
             'endpoint',
             'enable',
-            endpoint = 'filters.enable',
+            endpoint='filters.enable',
         )
         action_menu.add_entry(
             'endpoint',
             'delete',
-            endpoint = 'filters.delete',
+            endpoint='filters.delete',
         )
         action_menu.add_entry(
             'endpoint',
             'playground',
-            endpoint = 'filters.playground',
+            endpoint='filters.playground',
         )
         return action_menu
 
@@ -321,33 +329,33 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
         filter_tree = to_tree(item.filter)
         filter_compiled = tree_compile(filter_tree)
         self.response_context.update(
-            filter_tree = filter_tree,
-            filter_compiled = filter_compiled,
-            filter_preview = tree_html(filter_tree),
-            filter_compiled_preview = tree_html(filter_compiled)
+            filter_tree=filter_tree,
+            filter_compiled=filter_compiled,
+            filter_preview=tree_html(filter_tree),
+            filter_compiled_preview=tree_html(filter_compiled)
         )
 
-        if self.can_access_endpoint('filters.update', item = item) and self.has_endpoint('changelogs.search'):
+        if self.can_access_endpoint('filters.update', item=item) and self.has_endpoint('changelogs.search'):
             self.response_context.update(
-                context_action_menu_changelogs = self.get_endpoint_class(
+                context_action_menu_changelogs=self.get_endpoint_class(
                     'changelogs.search'
                 ).get_context_action_menu()
             )
 
-            item_changelog = self.dbsession.query(ItemChangeLogModel).\
-                filter(ItemChangeLogModel.model == item.__class__.__name__).\
-                filter(ItemChangeLogModel.model_id == item.id).\
-                order_by(ItemChangeLogModel.createtime.desc()).\
-                limit(100).\
+            item_changelog = self.dbsession.query(ItemChangeLogModel). \
+                filter(ItemChangeLogModel.model == item.__class__.__name__). \
+                filter(ItemChangeLogModel.model_id == item.id). \
+                order_by(ItemChangeLogModel.createtime.desc()). \
+                limit(100). \
                 all()
-            self.response_context.update(item_changelog = item_changelog)
+            self.response_context.update(item_changelog=item_changelog)
 
 
 class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for creating new reporting filters for any groups.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -369,38 +377,38 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        return vial.acl.PERMISSION_POWER.can()
+        return hawat.acl.PERMISSION_POWER.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['item'].group))
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['item'].group))
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_item_form(item):
-        detectors  = hawat.events.get_event_detectors()
+        detectors = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
         return AdminFilterForm(
-            choices_detectors  = list(zip(detectors,detectors)),
-            choices_categories = list(zip(categories,categories))
+            choices_detectors=list(zip(detectors, detectors)),
+            choices_categories=list(zip(categories, categories))
         )
 
     def do_before_action(self, item):  # pylint: disable=locally-disabled,no-self-use,unused-argument
@@ -411,16 +419,17 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
         if item:
             filter_tree = to_tree(item.filter)
             self.response_context.update(
-                filter_tree = filter_tree,
-                filter_preview = tree_html(filter_tree)
+                filter_tree=filter_tree,
+                filter_preview=tree_html(filter_tree)
             )
 
 
-class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
+class CreateForView(HTMLMixin, SQLAlchemyMixin,
+                    ItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for creating new reporting filters for given groups.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -438,14 +447,14 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: d
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Create reporting filter for group &quot;%(item)s&quot;',
-            item = flask.escape(str(kwargs['item']))
+            item=markupsafe.escape(str(kwargs['item']))
         )
 
     @classmethod
     def get_view_url(cls, **kwargs):
         return flask.url_for(
             cls.get_view_endpoint(),
-            parent_id = kwargs['item'].id
+            parent_id=kwargs['item'].id
         )
 
     @classmethod
@@ -467,40 +476,40 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: d
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].id)
+            hawat.acl.ManagementNeed(kwargs['item'].id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['parent']))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['parent']))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['parent']))
+            parent_id=markupsafe.escape(str(kwargs['parent']))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['parent']))
+            parent_id=markupsafe.escape(str(kwargs['parent']))
         )
 
     @staticmethod
     def get_item_form(item):
-        detectors  = hawat.events.get_event_detectors()
+        detectors = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
         return BaseFilterForm(
-            choices_detectors  = list(zip(detectors,detectors)),
-            choices_categories = list(zip(categories,categories))
+            choices_detectors=list(zip(detectors, detectors)),
+            choices_categories=list(zip(categories, categories))
         )
 
     @staticmethod
@@ -515,8 +524,8 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: d
         if item:
             filter_tree = to_tree(item.filter)
             self.response_context.update(
-                filter_tree = filter_tree,
-                filter_preview = tree_html(filter_tree)
+                filter_tree=filter_tree,
+                filter_preview=tree_html(filter_tree)
             )
 
 
@@ -524,7 +533,7 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     """
     View for updating existing reporting filters.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -532,7 +541,7 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Update details of reporting filter &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].name)
+            item=markupsafe.escape(kwargs['item'].name)
         )
 
     @classmethod
@@ -550,51 +559,51 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully updated.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to update reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled updating reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_item_form(item):
-        detectors  = hawat.events.get_event_detectors()
+        detectors = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
         admin = flask_login.current_user.has_role('admin')
         if not admin:
             return BaseFilterForm(
-                obj = item,
-                choices_detectors  = list(zip(detectors,detectors)),
-                choices_categories = list(zip(categories,categories))
+                obj=item,
+                choices_detectors=list(zip(detectors, detectors)),
+                choices_categories=list(zip(categories, categories))
             )
 
         return AdminFilterForm(
-            obj = item,
-            choices_detectors  = list(zip(detectors,detectors)),
-            choices_categories = list(zip(categories,categories))
+            obj=item,
+            choices_detectors=list(zip(detectors, detectors)),
+            choices_categories=list(zip(categories, categories))
         )
 
     def do_before_action(self, item):  # pylint: disable=locally-disabled,no-self-use,unused-argument
@@ -604,8 +613,8 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
         item = self.response_context['item']
         filter_tree = to_tree(item.filter)
         self.response_context.update(
-            filter_tree = filter_tree,
-            filter_preview = tree_html(filter_tree)
+            filter_tree=filter_tree,
+            filter_preview=tree_html(filter_tree)
         )
 
 
@@ -613,7 +622,7 @@ class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable
     """
     View for enabling existing reporting filters.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -621,7 +630,7 @@ class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Enable reporting filter &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].name)
+            item=markupsafe.escape(kwargs['item'].name)
         )
 
     @property
@@ -635,32 +644,32 @@ class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully enabled.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to enable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled enabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
 
@@ -668,7 +677,7 @@ class DisableView(HTMLMixin, SQLAlchemyMixin, ItemDisableView):  # pylint: disab
     """
     View for disabling existing reporting filters.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -676,10 +685,10 @@ class DisableView(HTMLMixin, SQLAlchemyMixin, ItemDisableView):  # pylint: disab
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Disable reporting filter &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].name)
+            item=markupsafe.escape(kwargs['item'].name)
         )
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
@@ -692,32 +701,32 @@ class DisableView(HTMLMixin, SQLAlchemyMixin, ItemDisableView):  # pylint: disab
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully disabled.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to disable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled disabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
 
@@ -725,7 +734,7 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     """
     View for deleting existing reporting filters.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -733,7 +742,7 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Delete reporting filter &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].name)
+            item=markupsafe.escape(kwargs['item'].name)
         )
 
     @property
@@ -747,32 +756,32 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully and permanently deleted.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to permanently delete reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled deleting reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
 
@@ -780,7 +789,7 @@ class PlaygroundView(HTMLMixin, RenderableView):
     """
     Reporting filter playground view.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -806,21 +815,21 @@ class PlaygroundView(HTMLMixin, RenderableView):
 
     @classmethod
     def get_breadcrumbs_menu(cls):
-        breadcrumbs_menu = vial.menu.Menu()
+        breadcrumbs_menu = hawat.menu.Menu()
         breadcrumbs_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['ENDPOINT_HOME']
+            endpoint=flask.current_app.config['ENDPOINT_HOME']
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
             'list',
-            endpoint = '{}.{}'.format(cls.module_name, 'list')
+            endpoint='{}.{}'.format(cls.module_name, 'list')
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
             'playground',
-            endpoint = cls.get_view_endpoint()
+            endpoint=cls.get_view_endpoint()
         )
         return breadcrumbs_menu
 
@@ -835,51 +844,50 @@ class PlaygroundView(HTMLMixin, RenderableView):
             form_data = form.data
 
             try:
-                event                   = Idea.from_json(form.event.data)
-                filter_tree             = to_tree(form.filter.data)
-                filter_preview          = tree_html(filter_tree)
-                filter_compiled         = tree_compile(filter_tree)
+                event = Idea.from_json(form.event.data)
+                filter_tree = to_tree(form.filter.data)
+                filter_preview = tree_html(filter_tree)
+                filter_compiled = tree_compile(filter_tree)
                 filter_compiled_preview = tree_html(filter_compiled)
-                filter_result           = tree_check(filter_compiled, event)
+                filter_result = tree_check(filter_compiled, event)
 
                 self.response_context.update(
-                    form_data               = form_data,
-                    event                   = event,
-                    filter_tree             = filter_tree,
-                    filter_preview          = filter_preview,
-                    filter_compiled         = filter_compiled,
-                    filter_compiled_preview = filter_compiled_preview,
-                    filter_result           = filter_result,
-                    flag_filtered           = True
+                    form_data=form_data,
+                    event=event,
+                    filter_tree=filter_tree,
+                    filter_preview=filter_preview,
+                    filter_compiled=filter_compiled,
+                    filter_compiled_preview=filter_compiled_preview,
+                    filter_result=filter_result,
+                    flag_filtered=True
                 )
 
             except Exception as err:  # pylint: disable=locally-disabled,broad-except
                 self.flash(
                     flask.Markup(gettext(
                         '<strong>%(error)s</strong>.',
-                        error = str(err)
+                        error=str(err)
                     )),
-                    vial.const.FLASH_FAILURE
+                    hawat.const.FLASH_FAILURE
                 )
 
                 tbexc = traceback.TracebackException(*sys.exc_info())
                 self.response_context.update(
-                    filter_exception    = err,
-                    filter_exception_tb = ''.join(tbexc.format())
+                    filter_exception=err,
+                    filter_exception_tb=''.join(tbexc.format())
                 )
 
-
         self.response_context.update(
-            form_url = flask.url_for(self.get_view_endpoint()),
-            form     = form,
+            form_url=flask.url_for(self.get_view_endpoint()),
+            form=form,
         )
         return self.generate_response()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
-class FiltersBlueprint(VialBlueprint):
+class FiltersBlueprint(HawatBlueprint):
     """Pluggable module - reporting filter management (*filters*)."""
 
     @classmethod
@@ -890,43 +898,43 @@ class FiltersBlueprint(VialBlueprint):
         app.menu_main.add_entry(
             'view',
             'admin.{}'.format(BLUEPRINT_NAME),
-            position = 60,
-            view = ListView
+            position=60,
+            view=ListView
         )
         app.menu_main.add_entry(
             'view',
             'more.{}_playground'.format(BLUEPRINT_NAME),
-            position = 1,
-            group = lazy_gettext('Tools'),
-            view = PlaygroundView
+            position=1,
+            group=lazy_gettext('Tools'),
+            view=PlaygroundView
         )
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 def get_blueprint():
     """
-    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
-    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    Mandatory interface for :py:mod:`hawat.Hawat` and factory function. This function
+    must return a valid instance of :py:class:`hawat.app.HawatBlueprint` or
     :py:class:`flask.Blueprint`.
     """
 
     hbp = FiltersBlueprint(
         BLUEPRINT_NAME,
         __name__,
-        template_folder = 'templates',
-        url_prefix = '/{}'.format(BLUEPRINT_NAME)
+        template_folder='templates',
+        url_prefix='/{}'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(ListView,       '/list')
-    hbp.register_view_class(CreateView,     '/create')
-    hbp.register_view_class(CreateForView,  '/createfor/<int:parent_id>')
-    hbp.register_view_class(ShowView,       '/<int:item_id>/show')
-    hbp.register_view_class(UpdateView,     '/<int:item_id>/update')
-    hbp.register_view_class(EnableView,     '/<int:item_id>/enable')
-    hbp.register_view_class(DisableView,    '/<int:item_id>/disable')
-    hbp.register_view_class(DeleteView,     '/<int:item_id>/delete')
+    hbp.register_view_class(ListView, '/list')
+    hbp.register_view_class(CreateView, '/create')
+    hbp.register_view_class(CreateForView, '/createfor/<int:parent_id>')
+    hbp.register_view_class(ShowView, '/<int:item_id>/show')
+    hbp.register_view_class(UpdateView, '/<int:item_id>/update')
+    hbp.register_view_class(EnableView, '/<int:item_id>/enable')
+    hbp.register_view_class(DisableView, '/<int:item_id>/disable')
+    hbp.register_view_class(DeleteView, '/<int:item_id>/delete')
     hbp.register_view_class(PlaygroundView, '/playground')
 
     return hbp
