@@ -1,27 +1,25 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 This module contains custom internal IP geolocation search form for Hawat.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import wtforms
 import flask_wtf
 from flask_babel import lazy_gettext
 
-import vial.forms
+import hawat.forms
 
 
 class GeoipSearchForm(flask_wtf.FlaskForm):
@@ -30,9 +28,9 @@ class GeoipSearchForm(flask_wtf.FlaskForm):
     """
     search = wtforms.StringField(
         lazy_gettext('Search GeoIP:'),
-        validators = [
+        validators=[
             wtforms.validators.DataRequired(),
-            vial.forms.check_ip_record
+            hawat.forms.check_ip_record
         ]
     )
     submit = wtforms.SubmitField(
