@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
@@ -19,11 +19,10 @@ features include:
 * deleting existing network records
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
+import markupsafe
 import flask
 import flask_login
 import flask_principal
@@ -33,13 +32,13 @@ from sqlalchemy import or_
 
 from mentat.datatype.sqldb import NetworkModel, GroupModel, ItemChangeLogModel
 
-import vial.acl
-from vial.app import VialBlueprint
-from vial.view import ItemListView, ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView, ItemDeleteView
-from vial.view.mixin import HTMLMixin, SQLAlchemyMixin
+import hawat.acl
+import hawat.menu
+from hawat.base import HawatBlueprint
+from hawat.view import ItemListView, ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView, ItemDeleteView
+from hawat.view.mixin import HTMLMixin, SQLAlchemyMixin
 from hawat.blueprints.networks.forms import BaseNetworkForm, AdminNetworkForm, NetworkSearchForm
 
-
 BLUEPRINT_NAME = 'networks'
 """Name of the blueprint as module global constant."""
 
@@ -52,7 +51,7 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     authentication = True
 
-    authorization = [vial.acl.PERMISSION_POWER]
+    authorization = [hawat.acl.PERMISSION_POWER]
 
     @classmethod
     def get_view_title(cls, **kwargs):
@@ -64,35 +63,35 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     @classmethod
     def get_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'create',
-            endpoint = 'networks.create',
-            resptitle = True
+            endpoint='networks.create',
+            resptitle=True
         )
         return action_menu
 
     @classmethod
     def get_context_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
-            endpoint = 'networks.show',
-            hidetitle = True
+            endpoint='networks.show',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'update',
-            endpoint = 'networks.update',
-            hidetitle = True
+            endpoint='networks.update',
+            hidetitle=True
         )
         action_menu.add_entry(
             'endpoint',
             'delete',
-            endpoint = 'networks.delete',
-            hidetitle = True
+            endpoint='networks.delete',
+            hidetitle=True
         )
         return action_menu
 
@@ -104,14 +103,14 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
         """
         return NetworkSearchForm(
             request_args,
-            meta = {'csrf': False}
+            meta={'csrf': False}
         )
 
     @staticmethod
     def build_query(query, model, form_args):
         # Adjust query based on text search string.
         if 'search' in form_args and form_args['search']:
-            query = query\
+            query = query \
                 .filter(
                     or_(
                         model.netname.like('%{}%'.format(form_args['search'])),
@@ -127,11 +126,11 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
             query = query.filter(model.createtime <= form_args['dt_to'])
         # Adjust query based on record source selection.
         if 'source' in form_args and form_args['source']:
-            query = query\
+            query = query \
                 .filter(model.source == form_args['source'])
         # Adjust query based on user membership selection.
         if 'group' in form_args and form_args['group']:
-            query = query\
+            query = query \
                 .filter(model.group_id == form_args['group'].id)
         if 'sortby' in form_args and form_args['sortby']:
             sortmap = {
@@ -158,7 +157,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'View details of network record &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].netname)
+            item=markupsafe.escape(kwargs['item'].netname)
         )
 
     @classmethod
@@ -172,51 +171,51 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_mm = flask_principal.Permission(
-            vial.acl.MembershipNeed(kwargs['item'].group.id),
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.MembershipNeed(kwargs['item'].group.id),
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_mm.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_mm.can()
 
     @classmethod
     def get_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
 
         action_menu.add_entry(
             'endpoint',
             'update',
-            endpoint = 'networks.update'
+            endpoint='networks.update'
         )
         action_menu.add_entry(
             'endpoint',
             'delete',
-            endpoint = 'networks.delete'
+            endpoint='networks.delete'
         )
 
         return action_menu
 
     def do_before_response(self, **kwargs):
         item = self.response_context['item']
-        if self.can_access_endpoint('networks.update', item = item) and self.has_endpoint('changelogs.search'):
+        if self.can_access_endpoint('networks.update', item=item) and self.has_endpoint('changelogs.search'):
             self.response_context.update(
-                context_action_menu_changelogs = self.get_endpoint_class(
+                context_action_menu_changelogs=self.get_endpoint_class(
                     'changelogs.search'
                 ).get_context_action_menu()
             )
 
-            item_changelog = self.dbsession.query(ItemChangeLogModel).\
-                filter(ItemChangeLogModel.model == item.__class__.__name__).\
-                filter(ItemChangeLogModel.model_id == item.id).\
-                order_by(ItemChangeLogModel.createtime.desc()).\
-                limit(100).\
+            item_changelog = self.dbsession.query(ItemChangeLogModel). \
+                filter(ItemChangeLogModel.model == item.__class__.__name__). \
+                filter(ItemChangeLogModel.model_id == item.id). \
+                order_by(ItemChangeLogModel.createtime.desc()). \
+                limit(100). \
                 all()
-            self.response_context.update(item_changelog = item_changelog)
+            self.response_context.update(item_changelog=item_changelog)
 
 
 class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for creating new network records.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -238,21 +237,21 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        return vial.acl.PERMISSION_POWER.can()
+        return hawat.acl.PERMISSION_POWER.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to create new network record for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['item'].group))
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
@@ -264,11 +263,12 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
         return AdminNetworkForm()
 
 
-class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
+class CreateForView(HTMLMixin, SQLAlchemyMixin,
+                    ItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for creating new network records.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -286,14 +286,14 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: d
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Create network record for group &quot;%(item)s&quot;',
-            item = flask.escape(str(kwargs['item']))
+            item=markupsafe.escape(str(kwargs['item']))
         )
 
     @classmethod
     def get_view_url(cls, **kwargs):
         return flask.url_for(
             cls.get_view_endpoint(),
-            parent_id = kwargs['item'].id
+            parent_id=kwargs['item'].id
         )
 
     @classmethod
@@ -315,23 +315,23 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: d
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].id)
+            hawat.acl.ManagementNeed(kwargs['item'].id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['parent']))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['parent']))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to create new network record for group <strong>%(parent_id)s</strong>.',
-            parent_id = flask.escape(str(kwargs['parent']))
+            parent_id=markupsafe.escape(str(kwargs['parent']))
         )
 
     @staticmethod
@@ -351,7 +351,7 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     """
     View for updating existing network records.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -359,7 +359,7 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Update details of network record &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].netname)
+            item=markupsafe.escape(kwargs['item'].netname)
         )
 
     @classmethod
@@ -377,48 +377,48 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully updated.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to update network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled updating network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_item_form(item):
         admin = flask_login.current_user.has_role('admin')
         if not admin:
-            return BaseNetworkForm(obj = item)
+            return BaseNetworkForm(obj=item)
 
-        return AdminNetworkForm(obj = item)
+        return AdminNetworkForm(obj=item)
 
 
 class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for deleting existing network records.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
@@ -426,7 +426,7 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Delete network record &quot;%(item)s&quot;',
-            item = flask.escape(kwargs['item'].netname)
+            item=markupsafe.escape(kwargs['item'].netname)
         )
 
     @property
@@ -440,39 +440,39 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     @classmethod
     def authorize_item_action(cls, **kwargs):
         permission_m = flask_principal.Permission(
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
+            hawat.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
             'Network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully and permanently deleted.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to permanently delete network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled deleting network record <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item'])),
-            parent_id = flask.escape(str(kwargs['item'].group))
+            item_id=markupsafe.escape(str(kwargs['item'])),
+            parent_id=markupsafe.escape(str(kwargs['item'].group))
         )
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
-class NetworksBlueprint(VialBlueprint):
+class NetworksBlueprint(HawatBlueprint):
     """Pluggable module - network management (*networks*)."""
 
     @classmethod
@@ -483,33 +483,33 @@ class NetworksBlueprint(VialBlueprint):
         app.menu_main.add_entry(
             'view',
             'admin.{}'.format(BLUEPRINT_NAME),
-            position = 70,
-            view = ListView
+            position=70,
+            view=ListView
         )
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 def get_blueprint():
     """
-    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
-    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    Mandatory interface for :py:mod:`hawat.Hawat` and factory function. This function
+    must return a valid instance of :py:class:`hawat.app.HawatBlueprint` or
     :py:class:`flask.Blueprint`.
     """
 
     hbp = NetworksBlueprint(
         BLUEPRINT_NAME,
         __name__,
-        template_folder = 'templates',
-        url_prefix = '/{}'.format(BLUEPRINT_NAME)
+        template_folder='templates',
+        url_prefix='/{}'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(ListView,      '/list')
-    hbp.register_view_class(CreateView,    '/create')
+    hbp.register_view_class(ListView, '/list')
+    hbp.register_view_class(CreateView, '/create')
     hbp.register_view_class(CreateForView, '/createfor/<int:parent_id>')
-    hbp.register_view_class(ShowView,      '/<int:item_id>/show')
-    hbp.register_view_class(UpdateView,    '/<int:item_id>/update')
-    hbp.register_view_class(DeleteView,    '/<int:item_id>/delete')
+    hbp.register_view_class(ShowView, '/<int:item_id>/show')
+    hbp.register_view_class(UpdateView, '/<int:item_id>/update')
+    hbp.register_view_class(DeleteView, '/<int:item_id>/delete')
 
     return hbp
