@@ -1,24 +1,22 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 This module contains custom network record management forms for Hawat.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import wtforms
-from wtforms.ext.sqlalchemy.fields import QuerySelectField
+from wtforms_sqlalchemy.fields import QuerySelectField
 
 #
 # Flask related modules.
@@ -28,10 +26,10 @@ from flask_babel import lazy_gettext
 #
 # Custom modules.
 #
-import vial.const
-import vial.forms
-import vial.db
-from vial.forms import get_available_groups
+import hawat.const
+import hawat.forms
+import hawat.db
+from hawat.forms import get_available_groups
 
 from mentat.datatype.sqldb import NetworkModel
 
@@ -40,43 +38,44 @@ def get_available_sources():
     """
     Query the database for list of network record sources.
     """
-    result = vial.db.db_query(NetworkModel)\
-        .distinct(NetworkModel.source)\
-        .order_by(NetworkModel.source)\
+    result = hawat.db.db_query(NetworkModel) \
+        .distinct(NetworkModel.source) \
+        .order_by(NetworkModel.source) \
         .all()
     return [x.source for x in result]
 
 
-class BaseNetworkForm(vial.forms.BaseItemForm):
+class BaseNetworkForm(hawat.forms.BaseItemForm):
     """
     Class representing base network record form.
     """
     netname = wtforms.StringField(
         lazy_gettext('Netname:'),
-        validators = [
+        validators=[
             wtforms.validators.DataRequired(),
-            wtforms.validators.Length(min = 3, max = 250)
+            wtforms.validators.Length(min=3, max=250),
+            hawat.forms.check_null_character
         ]
     )
     source = wtforms.HiddenField(
-        default = 'manual',
-        validators = [
+        default='manual',
+        validators=[
             wtforms.validators.DataRequired(),
-            wtforms.validators.Length(min = 3, max = 50)
+            wtforms.validators.Length(min=3, max=50)
         ]
     )
     network = wtforms.TextAreaField(
         lazy_gettext('Network:'),
-        validators = [
+        validators=[
             wtforms.validators.DataRequired(),
-            vial.forms.check_network_record
+            hawat.forms.check_network_record
         ]
     )
     rank = wtforms.IntegerField(
         lazy_gettext('Rank:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional(),
-            wtforms.validators.NumberRange(min = 1, max = 10000)
+            wtforms.validators.NumberRange(min=1, max=10000)
         ]
     )
     description = wtforms.TextAreaField(
@@ -96,65 +95,69 @@ class AdminNetworkForm(BaseNetworkForm):
     """
     group = QuerySelectField(
         lazy_gettext('Group:'),
-        query_factory = get_available_groups,
-        allow_blank = False
+        query_factory=get_available_groups,
+        allow_blank=False
     )
 
 
-class NetworkSearchForm(vial.forms.BaseSearchForm):
+class NetworkSearchForm(hawat.forms.BaseSearchForm):
     """
     Class representing simple user search form.
     """
     search = wtforms.StringField(
         lazy_gettext('Netname, network, description:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional(),
-            wtforms.validators.Length(min = 3, max = 100)
+            wtforms.validators.Length(min=3, max=100),
+            hawat.forms.check_null_character
         ],
-        description = lazy_gettext('Network`s name, address or description. Search is performed even in the middle of the strings.')
+        description=lazy_gettext(
+            'Network`s name, address or description. Search is performed even in the middle of the strings.')
     )
-    dt_from = vial.forms.SmartDateTimeField(
+    dt_from = hawat.forms.SmartDateTimeField(
         lazy_gettext('Creation time from:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        description = lazy_gettext('Lower time boundary for item creation time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences.')
+        description=lazy_gettext(
+            'Lower time boundary for item creation time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences.')
     )
-    dt_to = vial.forms.SmartDateTimeField(
+    dt_to = hawat.forms.SmartDateTimeField(
         lazy_gettext('Creation time to:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        description = lazy_gettext('Upper time boundary for item creation time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences.')
+        description=lazy_gettext(
+            'Upper time boundary for item creation time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences.')
     )
 
     group = QuerySelectField(
         lazy_gettext('Group:'),
-        query_factory = get_available_groups,
-        allow_blank = True
+        query_factory=get_available_groups,
+        allow_blank=True
     )
     source = wtforms.SelectField(
         lazy_gettext('Record source:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        default = ''
+        default=''
     )
 
     sortby = wtforms.SelectField(
         lazy_gettext('Sort by:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        choices = [
+        choices=[
             ('createtime.desc', lazy_gettext('by creation time descending')),
-            ('createtime.asc',  lazy_gettext('by creation time ascending')),
+            ('createtime.asc', lazy_gettext('by creation time ascending')),
             ('netname.desc', lazy_gettext('by netname descending')),
-            ('netname.asc',  lazy_gettext('by netname ascending')),
+            ('netname.asc', lazy_gettext('by netname ascending')),
             ('network.desc', lazy_gettext('by network descending')),
-            ('network.asc',  lazy_gettext('by network ascending'))
+            ('network.asc', lazy_gettext('by network ascending'))
         ],
-        default = 'netname.asc'
+        default='netname.asc'
     )
 
     def __init__(self, *args, **kwargs):
