@@ -1,27 +1,26 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 This pluggable module provides access to periodical event reports.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import re
 import os.path
 import datetime
 import dateutil.parser
 import pytz
+import markupsafe
 
 from jinja2.loaders import ChoiceLoader, FileSystemLoader
 import flask
@@ -39,12 +38,12 @@ from mentat.const import tr_
 
 import hawat.const
 
-import vial.menu
-import vial.acl
-from vial.app import VialBlueprint
-from vial.view import RenderableView, FileIdView, BaseSearchView, ItemShowView, ItemDeleteView
-from vial.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
-from vial.utils import URLParamsBuilder
+import hawat.menu
+import hawat.acl
+from hawat.base import HawatBlueprint
+from hawat.view import RenderableView, FileIdView, BaseSearchView, ItemShowView, ItemDeleteView
+from hawat.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
+from hawat.utils import URLParamsBuilder
 from hawat.blueprints.reports.forms import EventReportSearchForm, ReportingDashboardForm, \
     FeedbackForm
 
@@ -74,6 +73,7 @@ def build_related_search_params(item):
         )
     return related_events_search_params
 
+
 def adjust_query_for_groups(query, groups):
     """
     Adjust given SQLAlchemy query for current user. In case user specified set of
@@ -84,16 +84,17 @@ def adjust_query_for_groups(query, groups):
     # Adjust query to filter only selected groups.
     if groups:
         # Naive approach.
-        #query = query.filter(model.group_id.in_([grp.id for grp in groups]))
+        # query = query.filter(model.group_id.in_([grp.id for grp in groups]))
         # "Joined" approach.
         return query.join(_asoc_groups_reports).join(GroupModel).filter(GroupModel.id.in_([grp.id for grp in groups]))
 
     # For non-administrators restrict query only to groups they are member of.
-    if not flask_login.current_user.has_role(vial.const.ROLE_ADMIN):
+    if not flask_login.current_user.has_role(hawat.const.ROLE_ADMIN):
         # Naive approach.
-        #query = query.filter(model.group.has(GroupModel.members.any(UserModel.id == flask_login.current_user.id)))
+        # query = query.filter(model.group.has(GroupModel.members.any(UserModel.id == flask_login.current_user.id)))
         # "Joined" approach.
-        return query.join(_asoc_groups_reports).join(GroupModel).filter(GroupModel.members.any(UserModel.id == flask_login.current_user.id))
+        return query.join(_asoc_groups_reports).join(GroupModel).filter(
+            GroupModel.members.any(UserModel.id == flask_login.current_user.id))
 
     return query
 
@@ -124,7 +125,7 @@ class SearchView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disable
 
     @staticmethod
     def get_search_form(request_args):
-        return EventReportSearchForm(request_args, meta = {'csrf': False})
+        return EventReportSearchForm(request_args, meta={'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
@@ -152,7 +153,7 @@ class SearchView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disable
     def do_after_search(self, items):
         if items:
             self.response_context.update(
-                max_evcount_rep = max([x.evcount_rep for x in items])
+                max_evcount_rep=max([x.evcount_rep for x in items])
             )
 
 
@@ -172,7 +173,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'View details of event report &quot;%(item)s&quot;',
-            item = flask.escape(str(kwargs['item']))
+            item=markupsafe.escape(str(kwargs['item']))
         )
 
     @classmethod
@@ -187,72 +188,73 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     def authorize_item_action(cls, **kwargs):
         for group in kwargs['item'].groups:
             permission_mm = flask_principal.Permission(
-                vial.acl.MembershipNeed(group.id),
-                vial.acl.ManagementNeed(group.id)
+                hawat.acl.MembershipNeed(group.id),
+                hawat.acl.ManagementNeed(group.id)
             )
             if permission_mm.can():
                 return permission_mm.can()
-        return vial.acl.PERMISSION_POWER.can()
+        return hawat.acl.PERMISSION_POWER.can()
 
     @classmethod
     def get_breadcrumbs_menu(cls):  # pylint: disable=locally-disabled,unused-argument
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['ENDPOINT_HOME']
+            endpoint=flask.current_app.config['ENDPOINT_HOME']
         )
         action_menu.add_entry(
             'endpoint',
             'search',
-            endpoint = '{}.search'.format(cls.module_name)
+            endpoint='{}.search'.format(cls.module_name)
         )
         action_menu.add_entry(
             'endpoint',
             'show',
-            endpoint = '{}.show'.format(cls.module_name),
+            endpoint='{}.show'.format(cls.module_name),
         )
         return action_menu
 
     @classmethod
     def get_action_menu(cls):
-        action_menu = vial.menu.Menu()
+        action_menu = hawat.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'search',
-            endpoint = 'events.search',
-            title = lazy_gettext('Search'),
-            legend = lambda **x: lazy_gettext('Search for all events related to report &quot;%(item)s&quot;', item = flask.escape(x['item'].label)),
-            url = lambda **x: flask.url_for('events.search', **build_related_search_params(x['item']))
+            endpoint='events.search',
+            title=lazy_gettext('Search'),
+            legend=lambda **x: lazy_gettext('Search for all events related to report &quot;%(item)s&quot;',
+                                            item=markupsafe.escape(x['item'].label)),
+            url=lambda **x: flask.url_for('events.search', **build_related_search_params(x['item']))
         )
         action_menu.add_entry(
             'endpoint',
             'delete',
-            endpoint = 'reports.delete'
+            endpoint='reports.delete'
         )
         action_menu.add_entry(
             'submenu',
             'more',
-            align_right = True,
-            legend = lazy_gettext('More actions')
+            align_right=True,
+            legend=lazy_gettext('More actions')
         )
         action_menu.add_entry(
             'endpoint',
             'more.downloadjson',
-            endpoint = 'reports.data',
-            title = lazy_gettext('Download data in JSON format'),
-            url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'json'),
-            icon = 'action-download',
-            hidelegend = True
+            endpoint='reports.data',
+            title=lazy_gettext('Download data in JSON format'),
+            url=lambda **x: flask.url_for('reports.data', fileid=x['item'].label, filetype='json'),
+            icon='action-download',
+            hidelegend=True
         )
         action_menu.add_entry(
             'endpoint',
             'more.downloadjsonzip',
-            endpoint = 'reports.data',
-            title = lazy_gettext('Download compressed data in JSON format'),
-            url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'jsonzip'),
-            icon = 'action-download-zip',
-            hidelegend = True
+            endpoint='reports.data',
+            title=lazy_gettext('Download compressed data in JSON format'),
+            url=lambda **x: flask.url_for('reports.data', fileid=x['item'].label, filetype='jsonzip'),
+            icon='action-download-zip',
+            hidelegend=True
         )
         return action_menu
 
@@ -265,7 +267,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
         return format_datetime(
             dateutil.parser.parse(val).replace(tzinfo=pytz.utc).astimezone(tzone),
             BABEL_RFC3339_FORMAT,
-            rebase = False
+            rebase=False
         )
 
     @staticmethod
@@ -277,7 +279,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
         return format_datetime(
             dateutil.parser.parse(val).replace(tzinfo=pytz.utc).astimezone(tzone),
             format_str,
-            rebase = False
+            rebase=False
         )
 
     @staticmethod
@@ -290,21 +292,24 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
     def do_before_response(self, **kwargs):
         if 'item' in self.response_context and self.response_context['item']:
             self.response_context.update(
-                statistics         = self.response_context['item'].statistics,
-                template_vars      = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS],
-                form               = FeedbackForm(),
-                format_datetime    = ShowView.format_datetime,
-                format_datetime_wz = ShowView.format_datetime_wz,
-                tz                 = pytz.timezone(self.response_context['item'].structured_data["timezone"]) if self.response_context['item'].structured_data else None,
-                tz_utc             = pytz.utc,
-                event_classes_dir  = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR],
-                escape_id          = ShowView.escape_id
+                statistics=self.response_context['item'].statistics,
+                template_vars=flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][
+                    mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS],
+                form=FeedbackForm(),
+                format_datetime=ShowView.format_datetime,
+                format_datetime_wz=ShowView.format_datetime_wz,
+                tz=pytz.timezone(self.response_context['item'].structured_data["timezone"]) if self.response_context[
+                    'item'].structured_data else None,
+                tz_utc=pytz.utc,
+                event_classes_dir=flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][
+                    mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR],
+                escape_id=ShowView.escape_id
             )
             if self.response_context['item'].mail_to:
                 mails = self.response_context['item'].mail_to
                 self.response_context.update(
-                    to_mails = [x[3:] if x.startswith('to:') else x for x in mails if not x.startswith('cc:')],
-                    cc_mails = [x[3:] for x in mails if x.startswith('cc:')]
+                    to_mails=[x[3:] if x.startswith('to:') else x for x in mails if not x.startswith('cc:')],
+                    cc_mails=[x[3:] for x in mails if x.startswith('cc:')]
                 )
 
 
@@ -364,7 +369,7 @@ class DataView(FileIdView):
         elif filetype == 'jsonzip':
             fileext = 'json.zip'
         else:
-            raise ValueError("Requested invalid data file type '{}'".format(filetype))
+            flask.abort(400, "Requested invalid data file type '{}'".format(filetype))
         return 'security-report-{}.{}'.format(fileid, fileext)
 
 
@@ -396,7 +401,7 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
 
     @staticmethod
     def get_search_form(request_args):
-        return ReportingDashboardForm(request_args, meta = {'csrf': False})
+        return ReportingDashboardForm(request_args, meta={'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
@@ -420,10 +425,10 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
         if items:
             dt_from = self.response_context['form_data'].get('dt_from', None)
             if dt_from:
-                dt_from = dt_from.replace(tzinfo = None)
-            dt_to   = self.response_context['form_data'].get('dt_to', None)
+                dt_from = dt_from.replace(tzinfo=None)
+            dt_to = self.response_context['form_data'].get('dt_to', None)
             if dt_to:
-                dt_to = dt_to.replace(tzinfo = None)
+                dt_to = dt_to.replace(tzinfo=None)
 
             if not dt_from:
                 dt_from = self.dbcolumn_min(self.dbmodel.createtime)
@@ -443,12 +448,12 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
                 stats['emails'] = d
 
             self.response_context.update(
-                statistics = stats
+                statistics=stats
             )
 
     def do_before_response(self, **kwargs):
         self.response_context.update(
-            quicksearch_list = self.get_quicksearch_by_time()
+            quicksearch_list=self.get_quicksearch_by_time()
         )
 
 
@@ -488,17 +493,17 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     """
     View for deleting existing user accounts.
     """
-    methods = ['GET','POST']
+    methods = ['GET', 'POST']
 
     authentication = True
 
-    authorization = [vial.acl.PERMISSION_ADMIN]
+    authorization = [hawat.acl.PERMISSION_ADMIN]
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
         return lazy_gettext(
             'Delete event report &quot;%(item)s&quot;',
-            item = flask.escape(str(kwargs['item']))
+            item=markupsafe.escape(str(kwargs['item']))
         )
 
     def get_url_next(self):
@@ -518,21 +523,21 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
     def get_message_success(**kwargs):
         return gettext(
             'Event report <strong>%(item_id)s</strong> was successfully and permanently deleted.',
-            item_id = flask.escape(str(kwargs['item']))
+            item_id=markupsafe.escape(str(kwargs['item']))
         )
 
     @staticmethod
     def get_message_failure(**kwargs):
         return gettext(
             'Unable to delete event report <strong>%(item_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item']))
+            item_id=markupsafe.escape(str(kwargs['item']))
         )
 
     @staticmethod
     def get_message_cancel(**kwargs):
         return gettext(
             'Canceled deleting event report <strong>%(item_id)s</strong>.',
-            item_id = flask.escape(str(kwargs['item']))
+            item_id=markupsafe.escape(str(kwargs['item']))
         )
 
 
@@ -563,8 +568,10 @@ class FeedbackView(AJAXMixin, RenderableView):
         form = FeedbackForm(flask.request.form)
         if form.validate():
             mail_locale = flask.current_app.config['BABEL_DEFAULT_LOCALE']
-            link = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS]["report_access_url"] + \
-                item_id + "/unauth" + "#" + form.section.data
+            link = \
+            flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS][
+                "report_access_url"] + \
+            item_id + "/unauth" + "#" + form.section.data
             feedback_for = item_id + " (" + form.section.data + ", ip: " + form.ip.data + ")"
 
             with force_locale(mail_locale):
@@ -587,16 +594,18 @@ class FeedbackView(AJAXMixin, RenderableView):
             self.response_context["message"] = gettext('Thank you. Your feedback was sent to administrators.')
         else:
             self.response_context.update(
-                form_errors=[(field_name, err) for field_name, error_messages in form.errors.items() for err in error_messages]
+                form_errors=[(field_name, err) for field_name, error_messages in form.errors.items() for err in
+                             error_messages]
             )
-            self.response_context["message"] = "<br />".join([": ".join(err) for err in self.response_context["form_errors"]])
+            self.response_context["message"] = "<br />".join(
+                [": ".join(err) for err in self.response_context["form_errors"]])
         return self.generate_response()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
-class ReportsBlueprint(VialBlueprint):
+class ReportsBlueprint(HawatBlueprint):
     """Pluggable module - periodical event reports (*reports*)."""
 
     @classmethod
@@ -607,15 +616,15 @@ class ReportsBlueprint(VialBlueprint):
         app.menu_main.add_entry(
             'view',
             'dashboards.reporting',
-            position = 20,
-            view = DashboardView
+            position=20,
+            view=DashboardView
         )
         app.menu_main.add_entry(
             'view',
             BLUEPRINT_NAME,
-            position = 120,
-            view = SearchView,
-            resptitle = True
+            position=120,
+            view=SearchView,
+            resptitle=True
         )
 
         # Register context actions provided by this module.
@@ -623,14 +632,20 @@ class ReportsBlueprint(VialBlueprint):
             hawat.const.CSAG_ABUSE,
             tr_('Search for abuse group <strong>%(name)s</strong> in report database'),
             SearchView,
-            URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False, True).add_kwrule('dt_to', False, True)
+            URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False,
+                                                                                            True).add_kwrule('dt_to',
+                                                                                                             False,
+                                                                                                             True)
         )
 
         app.set_csag(
             hawat.const.CSAG_ABUSE,
             tr_('Search for abuse group <strong>%(name)s</strong> in reporting dashboards'),
             DashboardView,
-            URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False, True).add_kwrule('dt_to', False, True)
+            URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False,
+                                                                                            True).add_kwrule('dt_to',
+                                                                                                             False,
+                                                                                                             True)
         )
 
     @locked_cached_property
@@ -640,16 +655,19 @@ class ReportsBlueprint(VialBlueprint):
         .. versionadded:: 0.5
         """
         return ChoiceLoader([FileSystemLoader(os.path.join(self.root_path, self.template_folder)),
-                             FileSystemLoader(flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATESDIR]),
-                             FileSystemLoader(flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR])])
+                             FileSystemLoader(flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][
+                                                  mentat.const.CKEY_CORE_REPORTER_TEMPLATESDIR]),
+                             FileSystemLoader(flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][
+                                                  mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR])])
 
-#-------------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------------
 
 
 def get_blueprint():
     """
-    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
-    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    Mandatory interface for :py:mod:`hawat.Hawat` and factory function. This function
+    must return a valid instance of :py:class:`hawat.app.HawatBlueprint` or
     :py:class:`flask.Blueprint`.
     """
 
