@@ -1,24 +1,22 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 This module contains custom event report search form for Hawat.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import wtforms
-from wtforms.ext.sqlalchemy.fields import QuerySelectMultipleField
+from wtforms_sqlalchemy.fields import QuerySelectMultipleField
 
 import flask_login
 import flask_wtf
@@ -26,9 +24,9 @@ from flask_babel import lazy_gettext
 
 import mentat.const
 from mentat.datatype.sqldb import UserModel, GroupModel
-import vial.const
-import vial.forms
-import vial.db
+import hawat.const
+import hawat.forms
+import hawat.db
 import hawat.const
 
 
@@ -37,16 +35,17 @@ def get_available_groups():
     Query the database for list of all available groups.
     """
     # In case current user is administrator provide list of all groups.
-    if flask_login.current_user.has_role(vial.const.ROLE_ADMIN):
-        return vial.db.db_query(GroupModel).\
-            order_by(GroupModel.name).\
+    if flask_login.current_user.has_role(hawat.const.ROLE_ADMIN):
+        return hawat.db.db_query(GroupModel). \
+            order_by(GroupModel.name). \
             all()
-    # Otherwise provide only list of groups current user is member of.
-    return vial.db.db_query(GroupModel).\
-        filter(GroupModel.members.any(UserModel.id == flask_login.current_user.id)).\
-        order_by(GroupModel.name).\
+    # Otherwise, provide only list of groups current user is member of.
+    return hawat.db.db_query(GroupModel). \
+        filter(GroupModel.members.any(UserModel.id == flask_login.current_user.id)). \
+        order_by(GroupModel.name). \
         all()
 
+
 def get_severity_choices():
     """
     Return select choices for report severities.
@@ -58,6 +57,7 @@ def get_severity_choices():
         )
     )
 
+
 def get_type_choices():
     """
     Return select choices for report severities.
@@ -69,51 +69,53 @@ def get_type_choices():
         )
     )
 
-class EventReportSearchForm(vial.forms.BaseSearchForm):
+
+class EventReportSearchForm(hawat.forms.BaseSearchForm):
     """
     Class representing event report search form.
     """
     label = wtforms.StringField(
         lazy_gettext('Label:'),
-        validators = [
-            wtforms.validators.Optional()
+        validators=[
+            wtforms.validators.Optional(),
+            hawat.forms.check_null_character
         ]
     )
     groups = QuerySelectMultipleField(
         lazy_gettext('Groups:'),
-        query_factory = get_available_groups,
-        allow_blank = False,
-        get_pk = lambda item: item.name
+        query_factory=get_available_groups,
+        allow_blank=False,
+        get_pk=lambda item: item.name
     )
     severities = wtforms.SelectMultipleField(
         lazy_gettext('Severities:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional(),
         ],
-        choices = get_severity_choices(),
-        filters = [lambda x: x or []]
+        choices=get_severity_choices(),
+        filters=[lambda x: x or []]
     )
     types = wtforms.SelectMultipleField(
         lazy_gettext('Types:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional(),
         ],
-        choices = get_type_choices(),
-        filters = [lambda x: x or []]
+        choices=get_type_choices(),
+        filters=[lambda x: x or []]
     )
-    dt_from = vial.forms.SmartDateTimeField(
+    dt_from = hawat.forms.SmartDateTimeField(
         lazy_gettext('From:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        default = lambda: vial.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
+        default=lambda: hawat.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
     )
-    dt_to = vial.forms.SmartDateTimeField(
+    dt_to = hawat.forms.SmartDateTimeField(
         lazy_gettext('To:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        default = vial.forms.default_dt
+        default=hawat.forms.default_dt
     )
 
     @staticmethod
@@ -121,7 +123,7 @@ class EventReportSearchForm(vial.forms.BaseSearchForm):
         """
         Check, if given form field is a multivalue field.
 
-        :param str field_name: Name of the form field.
+        :param str field_name: Name of the form field
         :return: ``True``, if the field can contain multiple values, ``False`` otherwise.
         :rtype: bool
         """
@@ -136,23 +138,23 @@ class ReportingDashboardForm(flask_wtf.FlaskForm):
     """
     groups = QuerySelectMultipleField(
         lazy_gettext('Groups:'),
-        query_factory = get_available_groups,
-        allow_blank = False,
-        get_pk = lambda item: item.name
+        query_factory=get_available_groups,
+        allow_blank=False,
+        get_pk=lambda item: item.name
     )
-    dt_from = vial.forms.SmartDateTimeField(
+    dt_from = hawat.forms.SmartDateTimeField(
         lazy_gettext('From:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        default = lambda: vial.forms.default_dt_with_delta(vial.const.DEFAULT_RESULT_TIMEDELTA)
+        default=lambda: hawat.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
     )
-    dt_to = vial.forms.SmartDateTimeField(
+    dt_to = hawat.forms.SmartDateTimeField(
         lazy_gettext('To:'),
-        validators = [
+        validators=[
             wtforms.validators.Optional()
         ],
-        default = vial.forms.default_dt
+        default=hawat.forms.default_dt
     )
     submit = wtforms.SubmitField(
         lazy_gettext('Search')
@@ -163,7 +165,7 @@ class ReportingDashboardForm(flask_wtf.FlaskForm):
         """
         Check, if given form field is a multivalue field.
 
-        :param str field_name: Name of the form field.
+        :param str field_name: Name of the form field
         :return: ``True``, if the field can contain multiple values, ``False`` otherwise.
         :rtype: bool
         """
@@ -179,7 +181,7 @@ class FeedbackForm(flask_wtf.FlaskForm):
     ip = wtforms.HiddenField(
         validators=[
             wtforms.validators.DataRequired(),
-            vial.forms.check_network_record
+            hawat.forms.check_network_record
         ]
     )
     text = wtforms.TextAreaField(
