@@ -1,29 +1,28 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 Unit tests for :py:mod:`hawat.blueprints.status`.
 """
 
-
 import unittest
 
-import vial.const
-import vial.test
-import vial.db
+import hawat.const
+import hawat.test
+import hawat.db
 
-from vial.test import VialTestCase
+from hawat.test import HawatTestCase
 from hawat.test.runner import TestRunnerMixin
 
 
-class StatusViewTestCase(TestRunnerMixin, VialTestCase):
+class StatusViewTestCase(TestRunnerMixin, HawatTestCase):
     """Class for testing ``status.view`` endpoint."""
 
     def _attempt_fail_redirect(self):
@@ -34,7 +33,7 @@ class StatusViewTestCase(TestRunnerMixin, VialTestCase):
                 b'Redirecting...',
                 b'login?next='
             ],
-            follow_redirects = False
+            follow_redirects=False
         )
 
     def _attempt_fail(self):
@@ -56,28 +55,28 @@ class StatusViewTestCase(TestRunnerMixin, VialTestCase):
         """Test access as anonymous user."""
         self._attempt_fail_redirect()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_02_as_user(self):
         """Test access as user ``user``."""
         self._attempt_fail()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_03_as_developer(self):
         """Test access as user ``developer``."""
         self._attempt_fail()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_04_as_maintainer(self):
         """Test access as user ``maintainer``."""
         self._attempt_fail()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_05_as_admin(self):
         """Test access as user ``admin``."""
         self._attempt_succeed()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 if __name__ == "__main__":
