@@ -1,32 +1,31 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 Unit tests for :py:mod:`hawat.blueprints.users`.
 """
 
-
 import unittest
 
-import vial.const
-import vial.test
-import vial.test.fixtures
-from vial.test import VialTestCase, ItemCreateVialTestCase
+import hawat.const
+import hawat.test
+import hawat.test.fixtures
+from hawat.test import HawatTestCase, ItemCreateHawatTestCase
 from hawat.test.runner import TestRunnerMixin
 from hawat.blueprints.users.test.utils import UsersTestCaseMixin
 
 
-class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.list`` endpoint."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """
         Test access as user ``user``.
@@ -35,7 +34,7 @@ class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         """
         self._attempt_fail_list()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """
         Test access as user ``developer``.
@@ -44,7 +43,7 @@ class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         """
         self._attempt_fail_list()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """
         Test access as user ``maintainer``.
@@ -53,7 +52,7 @@ class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         """
         self._attempt_succeed_list()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """
         Test access as user ``admin``.
@@ -63,67 +62,67 @@ class UsersListTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         self._attempt_succeed_list()
 
 
-class UsersShowOwnTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersShowOwnTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """
     Class for testing ``users.show`` endpoint: access to user`s own accounts.
 
     Each user must be able to access his own account.
     """
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
-        self._attempt_succeed_show(vial.const.ROLE_USER)
+        self._attempt_succeed_show(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
-        self._attempt_succeed_show(vial.const.ROLE_DEVELOPER)
+        self._attempt_succeed_show(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
-        self._attempt_succeed_show(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_show(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
-        self._attempt_succeed_show(vial.const.ROLE_ADMIN)
+        self._attempt_succeed_show(hawat.const.ROLE_ADMIN)
 
 
-class UsersShowOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersShowOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.show`` endpoint: access to other user`s accounts."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user_developer(self):
         """
         Test access to 'developer' account as user 'user'.
 
         Regular user may view only his own account.
         """
-        self._attempt_fail_show(vial.const.ROLE_DEVELOPER)
+        self._attempt_fail_show(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_02_as_user_maintainer(self):
         """
         Test access to 'maintainer' account as user 'user'.
 
         Regular user may view only his own account.
         """
-        self._attempt_fail_show(vial.const.ROLE_MAINTAINER)
+        self._attempt_fail_show(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_03_as_user_admin(self):
         """
         Test access to 'admin' account as user 'user'.
 
         Regular user may view only his own account.
         """
-        self._attempt_fail_show(vial.const.ROLE_ADMIN)
+        self._attempt_fail_show(hawat.const.ROLE_ADMIN)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_04_as_developer_user(self):
         """
         Test access to 'user' account as user 'developer'.
@@ -131,9 +130,9 @@ class UsersShowOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         Developer should be able to access because he is a manager of group of
         which all other users are members.
         """
-        self._attempt_succeed_show(vial.const.ROLE_USER)
+        self._attempt_succeed_show(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_05_as_developer_maintainer(self):
         """
         Test access to 'maintainer' account as user 'developer'.
@@ -141,9 +140,9 @@ class UsersShowOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         Developer should be able to access because he is a manager of group of
         which all other users are members.
         """
-        self._attempt_succeed_show(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_show(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_06_as_developer_admin(self):
         """
         Test access to 'admin' account as user 'developer'.
@@ -151,56 +150,56 @@ class UsersShowOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
         Developer should be able to access because he is a manager of group of
         which all other users are members.
         """
-        self._attempt_succeed_show(vial.const.ROLE_ADMIN)
+        self._attempt_succeed_show(hawat.const.ROLE_ADMIN)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_07_as_maintainer_user(self):
         """
         Test access to 'user' account as user 'maintainer'.
 
         Maintainer should be allowed access, because he is a power user like admin.
         """
-        self._attempt_succeed_show(vial.const.ROLE_USER)
+        self._attempt_succeed_show(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_08_as_maintainer_developer(self):
         """
         Test access to 'developer' account as user 'maintainer'.
 
         Maintainer should be allowed access, because he is a power user like admin.
         """
-        self._attempt_succeed_show(vial.const.ROLE_DEVELOPER)
+        self._attempt_succeed_show(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_09_as_maintainer_admin(self):
         """
         Test access to 'maintainer' account as user 'maintainer'.
 
         Maintainer should be allowed access, because he is a power user like admin.
         """
-        self._attempt_succeed_show(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_show(hawat.const.ROLE_MAINTAINER)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_10_as_admin_user(self):
         """Test access to 'user' account as user 'admin'."""
-        self._attempt_succeed_show(vial.const.ROLE_USER)
+        self._attempt_succeed_show(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_11_as_admin_developer(self):
         """Test access to 'developer' account as user 'admin'."""
-        self._attempt_succeed_show(vial.const.ROLE_DEVELOPER)
+        self._attempt_succeed_show(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_12_as_admin_maintainer(self):
         """Test access to 'maintainer' account as user 'admin'."""
-        self._attempt_succeed_show(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_show(hawat.const.ROLE_MAINTAINER)
 
 
-class UsersCreateTestCase(UsersTestCaseMixin, TestRunnerMixin, ItemCreateVialTestCase):
+class UsersCreateTestCase(UsersTestCaseMixin, TestRunnerMixin, ItemCreateHawatTestCase):
     """Class for testing ``users.create`` endpoint."""
 
     user_data_fixture = [
@@ -211,172 +210,172 @@ class UsersCreateTestCase(UsersTestCaseMixin, TestRunnerMixin, ItemCreateVialTes
         ('enabled', True)
     ]
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
         self._attempt_fail_create()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
         self._attempt_fail_create()
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
         self._attempt_succeed_create(self.user_data_fixture)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
         self._attempt_succeed_create(self.user_data_fixture)
 
 
-class UsersUpdateOwnTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersUpdateOwnTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.update`` endpoint: access to user`s own accounts."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
-        self._attempt_succeed_update(vial.const.ROLE_USER)
+        self._attempt_succeed_update(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
-        self._attempt_succeed_update(vial.const.ROLE_DEVELOPER)
+        self._attempt_succeed_update(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
-        self._attempt_succeed_update(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_update(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
-        self._attempt_succeed_update(vial.const.ROLE_ADMIN)
+        self._attempt_succeed_update(hawat.const.ROLE_ADMIN)
 
 
-class UsersUpdateOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersUpdateOtherTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.update`` endpoint: access to other user`s accounts."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user_developer(self):
         """Test access to 'developer' account as user 'user'."""
-        self._attempt_fail_update(vial.const.ROLE_DEVELOPER)
+        self._attempt_fail_update(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_02_as_user_maintainer(self):
         """Test access to 'maintainer' account as user 'user'."""
-        self._attempt_fail_update(vial.const.ROLE_MAINTAINER)
+        self._attempt_fail_update(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_03_as_user_admin(self):
         """Test access to 'admin' account as user 'user'."""
-        self._attempt_fail_update(vial.const.ROLE_ADMIN)
+        self._attempt_fail_update(hawat.const.ROLE_ADMIN)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_04_as_developer_user(self):
         """Test access to 'user' account as user 'developer'."""
-        self._attempt_fail_update(vial.const.ROLE_USER)
+        self._attempt_fail_update(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_05_as_developer_maintainer(self):
         """Test access to 'maintainer' account as user 'developer'."""
-        self._attempt_fail_update(vial.const.ROLE_MAINTAINER)
+        self._attempt_fail_update(hawat.const.ROLE_MAINTAINER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_06_as_developer_admin(self):
         """Test access to 'admin' account as user 'developer'."""
-        self._attempt_fail_update(vial.const.ROLE_ADMIN)
+        self._attempt_fail_update(hawat.const.ROLE_ADMIN)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_07_as_maintainer_user(self):
         """Test access to 'user' account as user 'maintainer'."""
-        self._attempt_fail_update(vial.const.ROLE_USER)
+        self._attempt_fail_update(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_08_as_maintainer_developer(self):
         """Test access to 'developer' account as user 'maintainer'."""
-        self._attempt_fail_update(vial.const.ROLE_DEVELOPER)
+        self._attempt_fail_update(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_09_as_maintainer_admin(self):
         """Test access to 'admin' account as user 'maintainer'."""
-        self._attempt_fail_update(vial.const.ROLE_ADMIN)
+        self._attempt_fail_update(hawat.const.ROLE_ADMIN)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_10_as_admin_user(self):
         """Test access to 'user' account as user 'admin'."""
-        self._attempt_succeed_update(vial.const.ROLE_USER)
+        self._attempt_succeed_update(hawat.const.ROLE_USER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_11_as_admin_developer(self):
         """Test access to 'developer' account as user 'admin'."""
-        self._attempt_succeed_update(vial.const.ROLE_DEVELOPER)
+        self._attempt_succeed_update(hawat.const.ROLE_DEVELOPER)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_12_as_admin_maintainer(self):
         """Test access to 'maintainer' account as user 'admin'."""
-        self._attempt_succeed_update(vial.const.ROLE_MAINTAINER)
+        self._attempt_succeed_update(hawat.const.ROLE_MAINTAINER)
 
 
-class UsersEnableDisableTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersEnableDisableTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.enable`` and ``users.disable`` endpoint."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_fail_disable(uname)
             self._attempt_fail_enable(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_fail_disable(uname)
             self._attempt_fail_enable(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_succeed_disable(uname)
             self._attempt_succeed_enable(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER
+        ):
             self._attempt_succeed_disable(uname)
             self._attempt_succeed_enable(uname)
 
 
-class UsersAddRemRejMembershipTestCase(TestRunnerMixin, VialTestCase):
+class UsersAddRemRejMembershipTestCase(TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.add_membership``, ``users.reject_membership`` and ``users.remove_membership`` endpoint."""
 
     def _attempt_fail(self, uname, gname):
@@ -396,7 +395,7 @@ class UsersAddRemRejMembershipTestCase(TestRunnerMixin, VialTestCase):
             403
         )
 
-    def _attempt_succeed(self, uname, gname, print_response = False):
+    def _attempt_succeed(self, uname, gname, print_response=False):
         # Additional test preparations.
         with self.app.app_context():
             uid = self.user_id(uname)
@@ -501,96 +500,96 @@ class UsersAddRemRejMembershipTestCase(TestRunnerMixin, VialTestCase):
         )
         self.mailbox_monitoring('off')
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
-            self._attempt_fail(uname, vial.test.fixtures.DEMO_GROUP_A)
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
+            self._attempt_fail(uname, hawat.test.fixtures.DEMO_GROUP_A)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
-            self._attempt_succeed(uname, vial.test.fixtures.DEMO_GROUP_A)
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
+            self._attempt_succeed(uname, hawat.test.fixtures.DEMO_GROUP_A)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_ADMIN
-            ):
-            self._attempt_succeed(uname, vial.test.fixtures.DEMO_GROUP_A)
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_ADMIN
+        ):
+            self._attempt_succeed(uname, hawat.test.fixtures.DEMO_GROUP_A)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER
-            ):
-            self._attempt_succeed(uname, vial.test.fixtures.DEMO_GROUP_A)
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER
+        ):
+            self._attempt_succeed(uname, hawat.test.fixtures.DEMO_GROUP_A)
 
 
-class UsersDeleteTestCase(UsersTestCaseMixin, TestRunnerMixin, VialTestCase):
+class UsersDeleteTestCase(UsersTestCaseMixin, TestRunnerMixin, HawatTestCase):
     """Class for testing ``users.delete`` endpoint."""
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_USER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_USER)
     def test_01_as_user(self):
         """Test access as user 'user'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_fail_delete(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_DEVELOPER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_DEVELOPER)
     def test_02_as_developer(self):
         """Test access as user 'developer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_fail_delete(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_MAINTAINER)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_MAINTAINER)
     def test_03_as_maintainer(self):
         """Test access as user 'maintainer'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER,
-                vial.const.ROLE_ADMIN
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER,
+                hawat.const.ROLE_ADMIN
+        ):
             self._attempt_fail_delete(uname)
 
-    @vial.test.do_as_user_decorator(vial.const.ROLE_ADMIN)
+    @hawat.test.do_as_user_decorator(hawat.const.ROLE_ADMIN)
     def test_04_as_admin(self):
         """Test access as user 'admin'."""
         for uname in (
-                vial.const.ROLE_USER,
-                vial.const.ROLE_DEVELOPER,
-                vial.const.ROLE_MAINTAINER
-            ):
+                hawat.const.ROLE_USER,
+                hawat.const.ROLE_DEVELOPER,
+                hawat.const.ROLE_MAINTAINER
+        ):
             self._attempt_succeed_delete(uname)
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 if __name__ == "__main__":
