@@ -1,28 +1,26 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
 This module contains custom internal whois resolving search form for Hawat.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import ipranges
 import wtforms
 import flask_wtf
 from flask_babel import gettext, lazy_gettext
 
-import vial.const
+import hawat.const
 
 
 def check_search_data(form, field):  # pylint: disable=locally-disabled,unused-argument
@@ -36,7 +34,7 @@ def check_search_data(form, field):  # pylint: disable=locally-disabled,unused-a
     except ValueError:
         pass
 
-    if vial.const.CRE_EMAIL.match(field.data):
+    if hawat.const.CRE_EMAIL.match(field.data):
         return
 
     raise wtforms.validators.ValidationError(
@@ -50,7 +48,7 @@ class WhoisSearchForm(flask_wtf.FlaskForm):
     """
     search = wtforms.StringField(
         lazy_gettext('Search local WHOIS:'),
-        validators = [
+        validators=[
             wtforms.validators.DataRequired(),
             check_search_data
         ]
