@@ -1,41 +1,38 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # This file is part of Mentat system (https://mentat.cesnet.cz/).
 #
 # Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
 # Use of this source is governed by the MIT license, see LICENSE file.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 """
-This module contains application menu model for Hawat user interface.
+This module contains useful menu representation *Hawat* application.
 """
 
-
 __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
-
 import re
 import collections
 
+import werkzeug.routing
 import flask
 import flask_login
 import flask_principal
 
 import hawat.acl
 
-
 CRE_STRIP_QUESTION = re.compile(r'\?$')
 
-
-ENTRY_SUBMENU   = 'submenu'
+ENTRY_SUBMENU = 'submenu'
 ENTRY_SUBMENUDB = 'submenudb'
-ENTRY_VIEW      = 'view'
-ENTRY_ENDPOINT  = 'endpoint'
-ENTRY_LINK      = 'link'
-ENTRY_TEST      = 'test'
+ENTRY_VIEW = 'view'
+ENTRY_ENDPOINT = 'endpoint'
+ENTRY_LINK = 'link'
+ENTRY_TEST = 'test'
 
 
 def _url_segments(path):
@@ -44,8 +41,9 @@ def _url_segments(path):
         parts.pop()
     return parts
 
+
 def _is_active(this_url, request):
-    request_path      = request.script_root + request.path
+    request_path = request.script_root + request.path
     request_path_full = request.script_root + request.full_path
     # For some reason in certain cases the '?' is appended to the end of request
     # path event in case there are no additional parameters. Get rid of that.
@@ -77,27 +75,31 @@ def _filter_menu_entries(entries, **kwargs):
     """
     result = collections.OrderedDict()
     for entry_id, entry in entries.items():
-        #print("Processing menu entry '{}'.".format(entry_id))
+        # print("Processing menu entry '{}'.".format(entry_id))
 
         # Filter out entries protected with authentication.
         if entry.authentication:
             if not flask_login.current_user.is_authenticated:
-                #print("Hiding menu entry '{}', accessible only to authenticated users.".format(entry_id))
+                # print("Hiding menu entry '{}', accessible only to authenticated users.".format(entry_id))
                 continue
 
         # Filter out entries protected with authorization.
         if entry.authorization:
             hideflag = False
             for authspec in entry.authorization:
+                # When accessing static files, there is no identity in g so the can() function would raise an exception.
+                if not 'identity' in flask.g:
+                    hideflag = True
+                    break
                 # Authorization rules may be specified as instances of flask_principal.Permission.
                 if isinstance(authspec, flask_principal.Permission):
                     if not authspec.can():
-                        #print("Hiding menu entry '{}', accessible only to '{}'.".format(entry_id, str(authspec)))
+                        # print("Hiding menu entry '{}', accessible only to '{}'.".format(entry_id, str(authspec)))
                         hideflag = True
                 # Authorization rules may be specified as indices to hawat.acl permission dictionary.
                 else:
                     if not hawat.acl.PERMISSIONS[authspec].can():
-                        #print("Hiding menu entry '{}', accessible only to '{}'.".format(entry_id, str(authspec)))
+                        # print("Hiding menu entry '{}', accessible only to '{}'.".format(entry_id, str(authspec)))
                         hideflag = True
             if hideflag:
                 continue
@@ -105,7 +107,7 @@ def _filter_menu_entries(entries, **kwargs):
         if entry.type == ENTRY_SUBMENU:
             # Filter out empty submenus.
             if not _filter_menu_entries(entry._entries, **kwargs):  # pylint: disable=locally-disabled,protected-access
-                #print("Hiding menu entry '{}', empty submenu.".format(entry_id))
+                # print("Hiding menu entry '{}', empty submenu.".format(entry_id))
                 continue
 
         if entry.type == ENTRY_VIEW:
@@ -113,20 +115,21 @@ def _filter_menu_entries(entries, **kwargs):
             if hasattr(entry.view, 'authorize_item_action'):
                 params = entry._pick_params(kwargs)  # pylint: disable=locally-disabled,protected-access
                 if not entry.view.authorize_item_action(**params):
-                    #print("Hiding menu entry '{}', inaccessible item action for item '{}'.".format(entry_id, str(item)))
+                    # print("Hiding menu entry '{}', inaccessible item action for item '{}'.".format(entry_id, str(item)))
                     continue
 
             # Check item change validation callback, if exists.
             if hasattr(entry.view, 'validate_item_change'):
                 params = entry._pick_params(kwargs)  # pylint: disable=locally-disabled,protected-access
                 if not entry.view.validate_item_change(**params):
-                    #print("Hiding menu entry '{}', invalid item change for item '{}'.".format(entry_id, str(item)))
+                    # print("Hiding menu entry '{}', invalid item change for item '{}'.".format(entry_id, str(item)))
                     continue
 
         result[entry_id] = entry
 
     return result
 
+
 def _get_menu_entries(entries, **kwargs):
     """
     *Helper function*. Return filtered and sorted menu entries for current user.
@@ -140,34 +143,35 @@ def _get_menu_entries(entries, **kwargs):
         list(
             _filter_menu_entries(entries, **kwargs).values()
         ),
-        key = lambda x: x.position
+        key=lambda x: x.position
     )
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
-class MenuEntry:
+class MenuEntry:  # pylint: disable=locally-disabled,too-many-instance-attributes
     """
     Base class for all menu entries.
     """
+
     def __init__(self, ident, **kwargs):
-        self.type       = None
-        self.ident      = ident
-        self.position   = kwargs.get('position', 0)
-        self.group      = kwargs.get('group', None)
-        self._title     = kwargs.get('title', None)
-        self._icon      = kwargs.get('icon', None)
-        self._legend    = kwargs.get('legend', None)
-        self._params    = kwargs.get('params', None)
-        self.paramlist  = kwargs.get('paramlist', None)
-        self.hidetitle  = kwargs.get('hidetitle', False)
-        self.hideicon   = kwargs.get('hideicon', False)
+        self.type = None
+        self.ident = ident
+        self.position = kwargs.get('position', 0)
+        self.group = kwargs.get('group', None)
+        self._title = kwargs.get('title', None)
+        self._icon = kwargs.get('icon', None)
+        self._legend = kwargs.get('legend', None)
+        self._params = kwargs.get('params', None)
+        self.paramlist = kwargs.get('paramlist', None)
+        self.hidetitle = kwargs.get('hidetitle', False)
+        self.hideicon = kwargs.get('hideicon', False)
         self.hidelegend = kwargs.get('hidelegend', False)
-        self.resptitle  = kwargs.get('resptitle', False)
-        self.respicon   = kwargs.get('respicon', False)
+        self.resptitle = kwargs.get('resptitle', False)
+        self.respicon = kwargs.get('respicon', False)
         self.resplegend = kwargs.get('resplegend', False)
-        self.cssclass   = kwargs.get('cssclass', None)
+        self.cssclass = kwargs.get('cssclass', None)
 
     def __repr__(self):
         return '{}<type={},ident={}>'.format(
@@ -184,7 +188,7 @@ class MenuEntry:
             result = params
         if self.paramlist is not None:
             klist = result.keys() & self.paramlist
-            result = {k:result[k] for k in klist}
+            result = {k: result[k] for k in klist}
         return result
 
     def get_title(self, **kwargs):
@@ -269,11 +273,11 @@ class SubmenuEntry(MenuEntry):
 
     def __init__(self, ident, **kwargs):
         super().__init__(ident, **kwargs)
-        self.type           = ENTRY_SUBMENU
-        self.align_right    = kwargs.get('align_right', False)
+        self.type = ENTRY_SUBMENU
+        self.align_right = kwargs.get('align_right', False)
         self.authentication = kwargs.get('authentication', False)
-        self.authorization  = kwargs.get('authorization', [])
-        self._entry_list    = collections.OrderedDict()
+        self.authorization = kwargs.get('authorization', [])
+        self._entry_list = collections.OrderedDict()
 
     @property
     def _entries(self):
@@ -411,14 +415,18 @@ class ViewEntry(MenuEntry):
         :return: URL for current menu entry.
         :rtype: str
         """
-        params = self._pick_params(kwargs)
-        value = self._url or self.view.get_view_url(**params)
-        if value:
-            try:
-                return value(**params)
-            except TypeError:
-                return value
-        return flask.url_for(self.endpoint)
+        try:
+            params = self._pick_params(kwargs)
+            value = self._url or self.view.get_view_url(**params)
+            if value:
+                try:
+                    return value(**params)
+                except TypeError:
+                    return value
+            return flask.url_for(self.endpoint)
+        except werkzeug.routing.BuildError:
+            print("ERROR: Unable to build URL for {}:{}".format(self.ident, str(self.view)))
+            raise
 
     def get_entries(self, **kwargs):
         return []
@@ -431,7 +439,7 @@ class ViewEntry(MenuEntry):
         )
 
     def is_active(self, request, **kwargs):
-        #print("Checking if view menu entry '{}' is active.".format(self.ident))
+        # print("Checking if view menu entry '{}' is active.".format(self.ident))
         params = self._pick_params(kwargs)
         return _is_active(
             self.get_url(**params),
@@ -456,10 +464,10 @@ class LinkEntry(MenuEntry):
 
     def __init__(self, ident, **kwargs):
         super().__init__(ident, **kwargs)
-        self.type           = ENTRY_LINK
+        self.type = ENTRY_LINK
         self.authentication = kwargs.get('authentication', False)
-        self.authorization  = kwargs.get('authorization', [])
-        self._url           = kwargs.get('url')
+        self.authorization = kwargs.get('authorization', [])
+        self._url = kwargs.get('url')
 
     def get_url(self, **kwargs):
         """
@@ -486,7 +494,7 @@ class LinkEntry(MenuEntry):
         )
 
     def is_active(self, request, **kwargs):
-        #print("Checking if link menu entry '{}' is active.".format(self.ident))
+        # print("Checking if link menu entry '{}' is active.".format(self.ident))
         params = self._pick_params(kwargs)
         return _is_active(
             self.get_url(**params),
@@ -501,9 +509,9 @@ class TestEntry(MenuEntry):
 
     def __init__(self, ident, **kwargs):
         super().__init__(ident, **kwargs)
-        self.type           = ENTRY_TEST
+        self.type = ENTRY_TEST
         self.authentication = kwargs.get('authentication', False)
-        self.authorization  = kwargs.get('authorization', [])
+        self.authorization = kwargs.get('authorization', [])
 
     def get_entries(self, **kwargs):
         return []
@@ -525,6 +533,7 @@ class Menu:
     """
     Class for application menu.
     """
+
     def __init__(self):
         self._entries = collections.OrderedDict()
 
@@ -550,7 +559,7 @@ class Menu:
         :param dict kwargs: Additional arguments, that will be passed to the constructor of the appropriate entry class.
         """
         entry = None
-        if   entry_type == ENTRY_SUBMENU:
+        if entry_type == ENTRY_SUBMENU:
             entry = SubmenuEntry(ident, **kwargs)
         elif entry_type == ENTRY_SUBMENUDB:
             entry = DbSubmenuEntry(ident, **kwargs)
@@ -578,29 +587,28 @@ class Menu:
             self._entries[path[0]].add_entry(path[1], entry)
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 
 if __name__ == '__main__':
-
     MENU = Menu()
-    MENU.add_entry('test', 'test0', position = 10)
-    MENU.add_entry('test', 'test1', position = 10)
-    MENU.add_entry('test', 'test2', position = 20)
-    MENU.add_entry('test', 'test3', position = 40)
-    MENU.add_entry('test', 'test4', position = 30)
+    MENU.add_entry('test', 'test0', position=10)
+    MENU.add_entry('test', 'test1', position=10)
+    MENU.add_entry('test', 'test2', position=20)
+    MENU.add_entry('test', 'test3', position=40)
+    MENU.add_entry('test', 'test4', position=30)
 
-    MENU.add_entry('submenu', 'sub1', position = 50)
-    MENU.add_entry('submenu', 'sub2', position = 60)
+    MENU.add_entry('submenu', 'sub1', position=50)
+    MENU.add_entry('submenu', 'sub2', position=60)
 
-    MENU.add_entry('test', 'sub1.test1', position = 10)
-    MENU.add_entry('test', 'sub1.test2', position = 20)
-    MENU.add_entry('test', 'sub1.test3', position = 40)
-    MENU.add_entry('test', 'sub1.test4', position = 30)
-    MENU.add_entry('test', 'sub2.test1', position = 10)
-    MENU.add_entry('test', 'sub2.test2', position = 20)
-    MENU.add_entry('test', 'sub2.test3', position = 40)
-    MENU.add_entry('test', 'sub2.test4', position = 30)
+    MENU.add_entry('test', 'sub1.test1', position=10)
+    MENU.add_entry('test', 'sub1.test2', position=20)
+    MENU.add_entry('test', 'sub1.test3', position=40)
+    MENU.add_entry('test', 'sub1.test4', position=30)
+    MENU.add_entry('test', 'sub2.test1', position=10)
+    MENU.add_entry('test', 'sub2.test2', position=20)
+    MENU.add_entry('test', 'sub2.test3', position=40)
+    MENU.add_entry('test', 'sub2.test4', position=30)
 
     import pprint
 
