@@ -43,7 +43,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
                 'TestTag': {'ValueA1': 'A2', 'ValueA2': ['A4', 'A5']},
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'set': {
@@ -59,7 +59,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
                 'TestTag': {'ValueA1': 1466910407, 'ValueA2': [1466514007, 1466517607]},
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'report': {
@@ -74,7 +74,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Note': 'SSH login attempt',
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'drop': {
@@ -89,7 +89,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Note': 'SSH login attempt',
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'dispatch': {
@@ -104,7 +104,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Note': 'SSH login attempt',
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'duplicate': {
@@ -119,7 +119,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Note': 'SSH login attempt',
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         },
         'log': {
@@ -134,7 +134,7 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                 'Note': 'SSH login attempt',
                 'Source': [{'IP4': ['188.14.166.39']}],
                 'Target': [{'IP4': ['195.113.165.128/25'], 'Port': [22]}],
-                '_CESNET': {'StorageTime': '2016-06-21T14:00:07Z'}
+                '_Mentat': {'StorageTime': '2016-06-21T14:00:07Z'}
             }
         }
     }
@@ -301,12 +301,12 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
                             #'rule': 'Note EQ "SSH login attempt"',
                             #'name': 'rule_01',
                             #'actions': [
-                                #{'action': 'set', 'name': 'action_01', 'args': {'path': 'TestTag.ValueA1',    'expression': '_CESNET.StorageTime + 3600'}},
-                                #{'action': 'set', 'name': 'action_02', 'args': {'path': 'TestTag.ValueA1',    'expression': '_CESNET.StorageTime + 400000'}},
-                                #{'action': 'set', 'name': 'action_03', 'args': {'path': 'TestTag.ValueA1',    'expression': '_CESNET.StorageTime + 800000', 'overwrite': False}},
-                                #{'action': 'set', 'name': 'action_04', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_CESNET.StorageTime + 3600', 'unique': True}},
-                                #{'action': 'set', 'name': 'action_05', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_CESNET.StorageTime + 7200', 'unique': True}},
-                                #{'action': 'set', 'name': 'action_06', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_CESNET.StorageTime + 7200', 'unique': True}},
+                                #{'action': 'set', 'name': 'action_01', 'args': {'path': 'TestTag.ValueA1',    'expression': '_Mentat.StorageTime + 3600'}},
+                                #{'action': 'set', 'name': 'action_02', 'args': {'path': 'TestTag.ValueA1',    'expression': '_Mentat.StorageTime + 400000'}},
+                                #{'action': 'set', 'name': 'action_03', 'args': {'path': 'TestTag.ValueA1',    'expression': '_Mentat.StorageTime + 800000', 'overwrite': False}},
+                                #{'action': 'set', 'name': 'action_04', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_Mentat.StorageTime + 3600', 'unique': True}},
+                                #{'action': 'set', 'name': 'action_05', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_Mentat.StorageTime + 7200', 'unique': True}},
+                                #{'action': 'set', 'name': 'action_06', 'args': {'path': 'TestTag.ValueA2[*]', 'expression': '_Mentat.StorageTime + 7200', 'unique': True}},
                             #]
                         #},
                     #],
@@ -349,30 +349,30 @@ class TestMentatDaemonInspector(DaemonComponentTestCase):
         #daemon.logger.assert_has_calls([
                 #call.info("Inspecting message 'message01':'message01'"),
                 #call.info("Message 'message01':'message01' matched inspection rule 'rule_01'"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)"),
 
                 #call.info("Inspecting message 'message01':'message01'"),
                 #call.info("Message 'message01':'message01' matched inspection rule 'rule_01'"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)"),
 
                 #call.info("Inspecting message 'message01':'message01'"),
                 #call.info("Message 'message01':'message01' matched inspection rule 'rule_01'"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_CESNET.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
-                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_CESNET.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)")
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 400000'=>1466910407 key successfully set (O:True U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA1':'_Mentat.StorageTime + 800000'=>1467310407 key already exists, not overwriting (O:False U:False)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 3600'=>1466514007 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 key successfully set (O:True U:True)"),
+                #call.debug("Set - Message 'message01' path 'TestTag.ValueA2[*]':'_Mentat.StorageTime + 7200'=>1466517607 value already exists, not inserting (O:True U:True)")
             #])
 
     def test_04_report(self):
