@@ -19,7 +19,7 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 import unittest
 
-import mentat.daemon.piper
+#import mentat.daemon.piper
 
 
 class TestMentatBackupScript(unittest.TestCase):
