@@ -65,6 +65,7 @@ import sqlalchemy.dialects.postgresql
 from sqlalchemy.ext.declarative import declarative_base, declared_attr
 from sqlalchemy.schema import DropTable
 from sqlalchemy.ext.compiler import compiles
+from sqlalchemy.orm import validates
 
 from werkzeug.security import generate_password_hash, check_password_hash
 
@@ -187,9 +188,9 @@ class UserModel(MODEL):
     """
     __tablename__ = 'users'
 
-    login        = sqlalchemy.Column(sqlalchemy.String(50), unique = True, index = True)
+    login        = sqlalchemy.Column(sqlalchemy.String(50), sqlalchemy.CheckConstraint('login = lower(login)', name='login_lowercase'), unique = True, index = True)
     fullname     = sqlalchemy.Column(sqlalchemy.String(100), nullable = False)
-    email        = sqlalchemy.Column(sqlalchemy.String(250), nullable = False)
+    email        = sqlalchemy.Column(sqlalchemy.String(250), sqlalchemy.CheckConstraint('email = lower(email)', name='email_lowercase'), nullable = False)
     organization = sqlalchemy.Column(sqlalchemy.String(250), nullable = False)
     roles        = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String(20), dimensions = 1), nullable = False, default = [])
     password     = sqlalchemy.Column(sqlalchemy.String)
@@ -213,6 +214,13 @@ class UserModel(MODEL):
     def __str__(self):
         return '{}'.format(self.login)
 
+    @validates('login', 'email')
+    def convert_lower(self, key, value):  # pylint: disable=locally-disabled,no-self-use,unused-argument
+        """
+        Convert login and email to lowercase.
+        """
+        return value.lower()
+
     def is_state_enabled(self):
         """
         Check if current user account state is enabled.
