@@ -68,7 +68,7 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
 
         user1 = UserModel(login = 'user1@cesnet.cz', fullname = 'First User',  email = 'user1@cesnet.cz', organization = 'CESNET, z.s.p.o.')
         user2 = UserModel(login = 'user2@cesnet.cz', fullname = 'Second User', email = 'user2@cesnet.cz', organization = 'CESNET, z.s.p.o.', roles = ['admin'])
-        user3 = UserModel(login = 'user3@cesnet.cz', fullname = 'Third User',  email = 'user3@cesnet.cz', organization = 'CESNET, z.s.p.o.', roles = ['user', 'admin'], apikey = 'testapikey', locale = 'en', timezone = 'UTC')
+        user3 = UserModel(login = 'USER3@CESNET.CZ', fullname = 'Third User',  email = 'USER3@cesnet.cz', organization = 'CESNET, z.s.p.o.', roles = ['user', 'admin'], apikey = 'testapikey', locale = 'en', timezone = 'UTC')
 
         # Add single user object to session
         self.session.add(user1)
