@@ -36,9 +36,9 @@ Usage examples
 
     # Run in TEST DATA mode and MAIL TEST mode, force all reports to go to
     # 'admin@domain.org'. In test data mode only events tagged with 'Test'
-    # category will be processed (usefull for debugging). In mail test mode
+    # category will be processed (useful for debugging). In mail test mode
     # all generated reports will be redirected to configured admin email (root
-    # by default) instead of original contact, which is again usefull for
+    # by default) instead of original contact, which is again useful for
     # debugging or testing.
     mentat-reporter.py --mail-test-mode --test-data --mail-to admin@domain.org
 
@@ -161,11 +161,9 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
     CONFIG_EVENT_CLASSES_DIR   = 'event_classes_dir'
     CONFIG_TEMPLATE_VARS       = 'template_vars'
     CONFIG_FORCE_MODE          = 'force_mode'
-    CONFIG_FORCE_ATTACHMENTS   = 'force_attachments'
     CONFIG_FORCE_TEMPLATE      = 'force_template'
     CONFIG_FORCE_LOCALE        = 'force_locale'
     CONFIG_FORCE_TIMEZONE      = 'force_timezone'
-    CONFIG_FORCE_MAXATTACHSIZE = 'force_max_attachment_size'
     CONFIG_TEST_DATA           = 'test_data'
 
     def __init__(self):
@@ -234,12 +232,6 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
             default = None,
             help = 'force a reporting mode setting'
         )
-        arggroup_script.add_argument(
-            '--force-attachments',
-            type = str,
-            default = None,
-            help = 'force a report attachment setting'
-        )
         arggroup_script.add_argument(
             '--force-template',
             type = str,
@@ -258,12 +250,6 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
             default = None,
             help = 'force a timezone for generating reports'
         )
-        arggroup_script.add_argument(
-            '--force-max-attachment-size',
-            type = int,
-            default = None,
-            help = 'force maximal size of email attachments in bytes'
-        )
         arggroup_script.add_argument(
             '--test-data',
             action = 'store_true',
@@ -289,11 +275,9 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
         """
         cfgs = (
             (self.CONFIG_FORCE_MODE,          None),
-            (self.CONFIG_FORCE_ATTACHMENTS,   None),
             (self.CONFIG_FORCE_TEMPLATE,      None),
             (self.CONFIG_FORCE_LOCALE,        None),
             (self.CONFIG_FORCE_TIMEZONE,      None),
-            (self.CONFIG_FORCE_MAXATTACHSIZE, None),
             (self.CONFIG_TEST_DATA,           False)
         ) + cfgs
         return super()._init_config(cfgs, **kwargs)
@@ -357,17 +341,35 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
         # instance running.
         #
         with SimpleFlock("/var/tmp/mentat-reporter.py", 5):
+            groups_dict = {}
+            settings_dict = {}
+            for group in self._fetch_groups_enabled():
+                groups_dict[group.name] = group
+                settings_dict[group.name] = mentat.reports.utils.ReportingSettings(
+                                                group,
+                                                force_mode      = self.c(self.CONFIG_FORCE_MODE),
+                                                force_template  = self.c(self.CONFIG_FORCE_TEMPLATE),
+                                                force_locale    = self.c(self.CONFIG_FORCE_LOCALE),
+                                                force_timezone  = self.c(self.CONFIG_FORCE_TIMEZONE)
+                                            )
+            whoismodule = mentat.services.whois.SqldbWhoisModule()
+            whoismodule.setup()
+
             # Instantinate the reporter object.
             reporter = mentat.reports.event.EventReporter(
                 self.logger,
                 self.config[self.CORECFG_REPORTER][self.CONFIG_REPORTS_DIR],
                 self.config[self.CORECFG_REPORTER][self.CONFIG_TEMPLATES_DIR],
+                self.config[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_FALLBACK],
                 mentat.const.DFLT_REPORTING_LOCALE,
                 mentat.const.DFLT_REPORTING_TIMEZONE,
                 self.eventservice,
                 self.sqlservice,
                 self.mailerservice,
                 self.config[self.CORECFG_REPORTER][self.CONFIG_EVENT_CLASSES_DIR],
+                groups_dict,
+                settings_dict,
+                whoismodule,
                 self.c(self.CONFIG_REGULAR)
             )
 
@@ -383,11 +385,11 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
                 self.logger.info("Running in 'TESTDATA' mode: Reporting will be performed only for events tagged with 'Test' category.")
 
             # Perform reporting for all configured and enabled groups.
-            abuse_groups_enabled = self._fetch_groups_enabled()
-            for group in abuse_groups_enabled:
+            for group in groups_dict.values():
                 result['reports'][group.name] = self._report_for_group(
                     reporter,
                     group,
+                    settings_dict[group.name],
                     time_h
                 )
 
@@ -398,36 +400,26 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
 
     #---------------------------------------------------------------------------
 
-    def _report_for_group(self, reporter, abuse_group, time_h):
+    def _report_for_group(self, reporter, abuse_group, reporting_settings, time_h):
         """
         Perform event reporting for given group.
 
         :param mentat.reports.event.EventReporter reporter: Event reporter.
         :param mentat.datatype.internal.GroupModel abuse_group: Abuse group.
+        :param mentat.reports.utils.ReportingSettings reporting_settings: Reporting settings.
         :param datetime.datetime time_h: Upper reporting time boundary.
         :return: Dictionary structure containing information about reporting result.
         :rtype: dict
         """
         result = {}
 
-        # Transform reporting settings into more useful data structure.
-        reporting_settings = mentat.reports.utils.ReportingSettings(
-            abuse_group,
-            force_mode          = self.c(self.CONFIG_FORCE_MODE),
-            force_attachments   = self.c(self.CONFIG_FORCE_ATTACHMENTS),
-            force_template      = self.c(self.CONFIG_FORCE_TEMPLATE),
-            force_locale        = self.c(self.CONFIG_FORCE_LOCALE),
-            force_timezone      = self.c(self.CONFIG_FORCE_TIMEZONE),
-            force_maxattachsize = self.c(self.CONFIG_FORCE_MAXATTACHSIZE)
-        )
-
         # Perform reporting separatelly for each severity.
         for severity in mentat.const.EVENT_SEVERITIES:
             pstate_key = 'ts_last_{}_{}'.format(severity, abuse_group.name)
             period = reporting_settings.timing_cfg[severity]['per']
             time_l = self.pstate.get(pstate_key, None)
 
-            # In case we have timestamp of last successfull run, use it as lower
+            # In case we have timestamp of last successful run, use it as lower
             # threshold.
             if time_l:
                 time_l = datetime.datetime.fromtimestamp(time_l)
@@ -451,7 +443,6 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
             # Proceed to actual reporting.
             result[severity] = reporter.report(
                 abuse_group,
-                reporting_settings,
                 severity,
                 time_l,
                 time_h,
@@ -480,7 +471,7 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
                     str(time_h - time_l)
                 )
 
-            # Update the timestamp of last successfull reporting for particular
+            # Update the timestamp of last successful reporting for particular
             # severity ang abuse group.
             self.pstate[pstate_key] = time_h.timestamp()
 
@@ -489,6 +480,28 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
 
     #---------------------------------------------------------------------------
 
+    def _fetch_groups_from_events(self, time_h):
+        """
+        Fetch all abuse group names from events database for a given time window.
+
+        :return: Set of all abuse group names as strings.
+        :rtype: set
+        """
+        # Calculate lower threshold of considered events by using the longest period for reporting.
+        period = datetime.timedelta(seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_PER])
+        time_l = time_h - period
+        count, events = self.eventservice.search_events({
+            'st_from':        time_l,
+            'st_to':          time_h,
+            'groups':         ['__ANY__']
+        })
+        # Uniquify the found groups.
+        result = []
+        for e in events:
+            result.extend(e.get_abuses())
+        return set(result)
+
+    #---------------------------------------------------------------------------
 
     def _fetch_groups_enabled(self):
         """
@@ -537,7 +550,7 @@ class MentatReporterScript(mentat.script.fetcher.FetcherScript):
                         tmphlp['report_count'] += 1
                     if 'extra_id' in severity_stats and severity_stats['extra_id']:
                         tmphlp['extra_ids'].extend(severity_stats['extra_id'])
-                        tmphlp['abuse_groups'].extend(abuse_group)
+                        tmphlp['abuse_groups'].append(abuse_group)
                         tmphlp['report_count'] += len(severity_stats['extra_id'])
                     if 'mail_to' in severity_stats and severity_stats['mail_to']:
                         tmphlp['mails_to'].extend(severity_stats['mail_to'])
