@@ -25,6 +25,7 @@ from unittest.mock import call
 #
 from mentat.plugin.enricher.testsuite import MentatEnricherPluginTestCase
 from mentat.plugin.enricher.geoip import GeoipEnricherPlugin
+from mentat.const import CKEY_CORE_SERVICES, CKEY_CORE_SERVICES_GEOIP
 
 
 #-------------------------------------------------------------------------------
@@ -56,10 +57,13 @@ class TestMentatGeoipEnricherPlugin(MentatEnricherPluginTestCase):
         mapplication = self._build_application_mock([])
 
         self.plugin.setup(mapplication)
+        asndb = mapplication.config[CKEY_CORE_SERVICES][CKEY_CORE_SERVICES_GEOIP]['asndb']
+        citydb = mapplication.config[CKEY_CORE_SERVICES][CKEY_CORE_SERVICES_GEOIP]['citydb']
+        config = "{'asn': '%s',\n 'city': '%s',\n 'country': None}" % (asndb, citydb)
         self._verbose_print("TEST01: daemon mock calls after plugin 'setup'", mapplication.mock_calls)
 
         mapplication.assert_has_calls([
-            call.logger.info("Initialized '%s' enricher plugin: %s", 'GeoipEnricherPlugin', "{'asn': '/usr/share/GeoIP/GeoLite2-ASN.mmdb',\n 'city': '/usr/share/GeoIP/GeoLite2-City.mmdb',\n 'country': None}")
+            call.logger.info("Initialized '%s' enricher plugin: %s", 'GeoipEnricherPlugin', config)
         ])
 
     def test_02_process_01(self):
@@ -76,10 +80,6 @@ class TestMentatGeoipEnricherPlugin(MentatEnricherPluginTestCase):
         }
 
         self.plugin.setup(mapplication)
-        mapplication.assert_has_calls([
-            call.logger.info("Initialized '%s' enricher plugin: %s", 'GeoipEnricherPlugin', "{'asn': '/usr/share/GeoIP/GeoLite2-ASN.mmdb',\n 'city': '/usr/share/GeoIP/GeoLite2-City.mmdb',\n 'country': None}"),
-        ])
-        mapplication.reset_mock()
 
         result = self.plugin.process(mapplication, 'msgid', msg)
         self._verbose_print("TEST02: daemon mock calls after plugin 'setup'", mapplication.mock_calls)
@@ -114,10 +114,6 @@ class TestMentatGeoipEnricherPlugin(MentatEnricherPluginTestCase):
         }
 
         self.plugin.setup(mapplication)
-        mapplication.assert_has_calls([
-            call.logger.info("Initialized '%s' enricher plugin: %s", 'GeoipEnricherPlugin', "{'asn': '/usr/share/GeoIP/GeoLite2-ASN.mmdb',\n 'city': '/usr/share/GeoIP/GeoLite2-City.mmdb',\n 'country': None}"),
-        ])
-        mapplication.reset_mock()
 
         result = self.plugin.process(mapplication, 'msgid', msg)
         self._verbose_print("TEST02: daemon mock calls after plugin 'setup'", mapplication.mock_calls)
