@@ -186,7 +186,7 @@ class EventReporter(BaseReporter):
             events_passed_filters, aggregated_events, fltlog, passed_cnt = self.filter_events(abuse_group.name, events_fetched)
             for groups in aggregated_events:
                 group_chain = groups[0]
-                if group_chain not in result:
+                if str(group_chain) not in result:
                     result[str(group_chain)] = {}
                 result[str(group_chain)]['evcount_all'] = len(events_passed_filters[groups])
                 result[str(group_chain)]['evcount_new'] = result[str(group_chain)]['evcount_all']
@@ -237,7 +237,7 @@ class EventReporter(BaseReporter):
             events_rel, events_aggregated, fltlog, passed_cnt = self.filter_events(abuse_group.name, map(record_to_idea, events_rel))
             for groups, events_aggr in events_aggregated.items():
                 group_chain = groups[0]
-                if group_chain not in result:
+                if str(group_chain) not in result:
                     result[str(group_chain)] = {}
                     result[str(group_chain)]['evcount_all'] = 0
                 result[str(group_chain)]['evcount_rlp'] = len(events_rel[groups])
