@@ -18,7 +18,7 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 import os
 import unittest
-from unittest.mock import Mock, call
+from unittest.mock import MagicMock, Mock, call
 import datetime
 
 #
@@ -80,7 +80,7 @@ class TestMentatReportsEvent(unittest.TestCase):
                     'SW': ['Kippo']
                 }
             ],
-            '_CESNET' : {
+            '_Mentat' : {
                 'ResolvedAbuses' : [
                     'abuse@cesnet.cz'
                 ],
@@ -113,7 +113,7 @@ class TestMentatReportsEvent(unittest.TestCase):
                 }
             ],
             'Note': 'Test note containing ; CSV delimiter.',
-            '_CESNET' : {
+            '_Mentat' : {
                 'ResolvedAbuses' : [
                     'abuse@cesnet.cz'
                 ],
@@ -153,10 +153,11 @@ class TestMentatReportsEvent(unittest.TestCase):
         self.eventstorage.database_drop()
         self.eventstorage.database_create()
         for event in self.ideas_obj:
-            event['_CESNET']['StorageTime'] = datetime.datetime.utcnow()
+            event['_Mentat']['StorageTime'] = datetime.datetime.utcnow()
             self.eventstorage.insert_event(event)
 
         group = GroupModel(name = 'abuse@cesnet.cz',  source = 'manual', description = 'CESNET, z.s.p.o.')
+        groups_dict = {'abuse@cesnet.cz': group}
 
         FilterModel(group = group, name = 'FLT1', type = 'basic', filter = 'Node.Name == "org.example.kippo_honey"', description = 'DESC1', enabled = True)
         FilterModel(group = group, name = 'FLT2', type = 'basic', filter = 'Source.IP4 IN [10.0.0.0/24]', description = 'DESC2', enabled = True)
@@ -168,17 +169,31 @@ class TestMentatReportsEvent(unittest.TestCase):
         self.sqlstorage.session.commit()
 
         self.reporting_settings = mentat.reports.utils.ReportingSettings(group)
+        settings_dict = {'abuse@cesnet.cz': self.reporting_settings}
+
+        def lookup_mock(src, getall = False):
+            if str(src).startswith('10.'):
+                return [{'abuse_group': 'abuse@cesnet.cz', 'is_base': False}]
+            else:
+                return []
+
+        whoismodule_mock = mentat.services.whois.WhoisModule()
+        whoismodule_mock.lookup = MagicMock(side_effect = lookup_mock)
 
         self.reporter = mentat.reports.event.EventReporter(
             Mock(),
             REPORTS_DIR,
             os.path.abspath(os.path.join(os.path.dirname(__file__), '../../../conf/templates/reporter')),
+            [],
             'en',
             'UTC',
             self.eventstorage,
             self.sqlstorage,
             mailer = None,
-            event_classes_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../../../conf/event_classes'))
+            event_classes_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../../../conf/event_classes')),
+            groups_dict = groups_dict,
+            settings_dict = settings_dict,
+            whoismodule = whoismodule_mock
         )
 
     def tearDown(self):
@@ -186,14 +201,7 @@ class TestMentatReportsEvent(unittest.TestCase):
         self.sqlstorage.database_drop()
         self.eventstorage.database_drop()
 
-    def test_01_csv_dict(self):
-        """
-        Test :py:func:`mentat.reports.event.csv_dict` function.
-        """
-        #pprint([mentat.reports.event.csv_dict(x) for x in self.ideas_obj])
-        self.assertTrue([mentat.reports.event.csv_dict(x) for x in self.ideas_obj])
-
-    def test_02_save_to_json_files(self):
+    def test_01_save_to_json_files(self):
         """
         Test :py:func:`mentat.reports.event.EventReporter._save_to_json_files` function.
         """
@@ -239,53 +247,7 @@ class TestMentatReportsEvent(unittest.TestCase):
         os.unlink(report_path)
         os.unlink("{}.zip".format(report_path))
 
-    def test_03_save_to_csv_files(self):
-        """
-        Test :py:func:`mentat.reports.event.EventReporter._save_to_csv_files` function.
-        """
-        self.maxDiff = None
-
-        # Test saving file without timestamp information.
-        report_file = 'utest-security-report.csv'
-        report_path = os.path.join(REPORTS_DIR, report_file)
-
-        self.assertEqual(
-            self.reporter._save_to_csv_files( # pylint: disable=locally-disabled,protected-access
-                self.ideas_obj,
-                report_file
-            ),
-            (report_path, "{}.zip".format(report_path))
-        )
-        self.assertTrue(
-            os.path.isfile(report_path)
-        )
-        self.assertTrue(
-            os.path.isfile("{}.zip".format(report_path))
-        )
-        os.unlink(report_path)
-        os.unlink("{}.zip".format(report_path))
-
-        # Test saving file with timestamp information.
-        report_file = 'utest-security-report-M20180726SL-HT9TC.csv'
-        report_path = os.path.join(REPORTS_DIR, '20180726', report_file)
-
-        self.assertEqual(
-            self.reporter._save_to_csv_files( # pylint: disable=locally-disabled,protected-access
-                self.ideas_obj,
-                report_file
-            ),
-            (report_path, "{}.zip".format(report_path))
-        )
-        self.assertTrue(
-            os.path.isfile(report_path)
-        )
-        self.assertTrue(
-            os.path.isfile("{}.zip".format(report_path))
-        )
-        os.unlink(report_path)
-        os.unlink("{}.zip".format(report_path))
-
-    def test_04_save_to_files(self):
+    def test_02_save_to_files(self):
         """
         Test :py:func:`mentat.reports.event.EventReporter._save_to_files` function.
         """
@@ -331,7 +293,7 @@ class TestMentatReportsEvent(unittest.TestCase):
         os.unlink(report_path)
         os.unlink("{}.zip".format(report_path))
 
-    def test_05_filter_events(self):
+    def test_03_filter_events(self):
         """
         Test :py:class:`mentat.reports.event.EventReporter.filter_events` function.
         """
@@ -340,35 +302,39 @@ class TestMentatReportsEvent(unittest.TestCase):
         abuse_group = self.sqlstorage.session.query(GroupModel).filter(GroupModel.name == 'abuse@cesnet.cz').one()
         self.sqlstorage.session.commit()
 
-        reporting_settings = mentat.reports.utils.ReportingSettings(
-            abuse_group
-        )
-        events, aggr, fltlog = self.reporter.filter_events(self.ideas_obj, abuse_group, reporting_settings)
-        self.assertEqual(fltlog, {'FLT1': 1})
-        self.assertEqual(len(aggr), 2)
+        events, aggr, fltlog, flt_cnt = self.reporter.filter_events(abuse_group.name, self.ideas_obj)
+        self.assertEqual(fltlog, {'FLT1': 1, 'FLT2': 1, 'FLT3': 1})
+        self.assertEqual(flt_cnt, 1)
+        for events in aggr.values():
+            self.assertEqual(len(events), 2)
         self.reporter.logger.assert_has_calls([
-            call.debug("Event matched filtering rule '%s', all sources filtered", 'FLT1'),
-            call.debug("Event matched filtering rule '%s', some sources allowed through", 'FLT2'),
-            call.info('%s: Filters let %d events through, %d blocked.', 'abuse@cesnet.cz', 1, 1)
+            call.debug("Event matched filtering rule '%s' of group %s.", 'FLT1', 'abuse@cesnet.cz'),
+            call.debug("Discarding event with ID '%s' from reports.", 'msg01'),
+            call.debug('Event matched filtering rules, all sources filtered'),
+            call.debug("Event matched filtering rule '%s' of group %s.", 'FLT3', 'abuse@cesnet.cz'),
+            call.debug("Discarding event with ID '%s' from reports.", 'msg02'),
+            call.debug("Event matched filtering rule '%s' of group %s.", 'FLT2', 'abuse@cesnet.cz'),
+            call.debug("Discarding event with ID '%s' from reports.", 'msg02')
         ])
         self.sqlstorage.session.commit()
 
-        events, aggr, fltlog = self.reporter.filter_events(self.ideas_obj, abuse_group, reporting_settings)
+        events, aggr, fltlog, flt_cnt = self.reporter.filter_events(abuse_group.name, self.ideas_obj)
         self.sqlstorage.session.commit()
         flt1 = self.sqlstorage.session.query(FilterModel).filter(FilterModel.name == 'FLT1').one()
         self.assertEqual(flt1.hits, 2)
 
-        events, aggr, fltlog = self.reporter.filter_events(self.ideas_obj, abuse_group, reporting_settings)
-        events, aggr, fltlog = self.reporter.filter_events(self.ideas_obj, abuse_group, reporting_settings)
+        events, aggr, fltlog, flt_cnt = self.reporter.filter_events(abuse_group.name, self.ideas_obj)
+        events, aggr, fltlog, flt_cnt = self.reporter.filter_events(abuse_group.name, self.ideas_obj)
         self.sqlstorage.session.commit()
         flt1 = self.sqlstorage.session.query(FilterModel).filter(FilterModel.name == 'FLT1').one()
         self.assertEqual(flt1.hits, 4)
 
-        aggr = self.reporter.aggregate_events(aggr)
+        for aggr in aggr.values():
+            aggr = self.reporter.aggregate_events(aggr)
         self.assertEqual(list(sorted(aggr.keys())), ['anomaly-traffic'])
         self.assertEqual(list(aggr['anomaly-traffic'].keys()), ['10.0.2.1', '10.0.0.0/22'])
 
-    def test_06_fetch_severity_events(self):
+    def test_04_fetch_severity_events(self):
         """
         Test :py:class:`mentat.reports.event.EventReporter.fetch_severity_events` function.
         """
@@ -401,7 +367,7 @@ class TestMentatReportsEvent(unittest.TestCase):
         )
         self.assertEqual(list(map(lambda x: x['ID'], events)), [])
 
-    def test_07_j2t_idea_path_valueset(self):
+    def test_05_j2t_idea_path_valueset(self):
         """
         Test :py:class:`mentat.reports.event.EventReporter.j2t_idea_path_valueset` function.
         """
@@ -434,7 +400,7 @@ class TestMentatReportsEvent(unittest.TestCase):
             ['https', 'ssh']
         )
 
-    def test_08_render_report_summary(self):
+    def test_06_render_report_summary(self):
         """
         Test :py:class:`mentat.reports.event.EventReporter.render_report_summary` function.
         """
@@ -475,7 +441,7 @@ class TestMentatReportsEvent(unittest.TestCase):
         self.assertTrue(report_txt)
         self.assertEqual(report_txt.split('\n')[0], 'Vážení kolegové.')
 
-    def test_09_render_report_extra(self):
+    def test_07_render_report_extra(self):
         """
         Test :py:class:`mentat.reports.event.EventReporter.render_report_extra` function.
         """
@@ -492,7 +458,6 @@ class TestMentatReportsEvent(unittest.TestCase):
             ),
             self.reporting_settings,
             self.template_vars,
-            ["file1.json"],
             '192.168.1.1'
         )
         print("\n---\nEXTRA REPORT IN EN:\n---\n")
@@ -511,7 +476,6 @@ class TestMentatReportsEvent(unittest.TestCase):
             ),
             self.reporting_settings,
             self.template_vars,
-            ["file1.json"],
             '192.168.1.1'
         )
         print("\n---\nEXTRA REPORT IN CS:\n---\n")
@@ -524,7 +488,7 @@ class TestMentatReportsEvent(unittest.TestCase):
 
     def _generate_mock_report(self, abuse_group, severity, rtype):
         report = EventReportModel(
-            group    = abuse_group,
+            groups   = [abuse_group],
             severity = severity,
             type     = rtype,
             dt_from  = datetime.datetime.utcnow() - datetime.timedelta(seconds=3600),
@@ -545,7 +509,7 @@ class TestMentatReportsEvent(unittest.TestCase):
 
         if rtype == mentat.const.REPORTING_MODE_EXTRA:
             report.parent = EventReportModel(
-                group    = abuse_group,
+                groups   = [abuse_group],
                 severity = severity,
                 type     = mentat.const.REPORTING_MODE_SUMMARY,
                 dt_from  = datetime.datetime.utcnow() - datetime.timedelta(seconds=3600),
