@@ -36,43 +36,35 @@ class ReportingSettings: # pylint: disable=locally-disabled,too-many-instance-at
         self.group_name  = abuse_group.name
         self.filters     = abuse_group.filters
         self.networks    = abuse_group.networks
-        self.emails      = self._init_emails(abuse_group.name, abuse_group.settings_rep.emails)
+        self.emails      = self._init_emails(abuse_group.name, abuse_group.settings_rep)
         self.mode        = self._init_mode(abuse_group.settings_rep.mode, **kwargs)
-        self.attachments = self._init_attachments(abuse_group.settings_rep.attachments, **kwargs)
-        self.template    = self._init_template(abuse_group.settings_rep.template, **kwargs)
+        self.template    = self._init_template(**kwargs)
         self.locale      = self._init_locale(abuse_group.settings_rep.locale, **kwargs)
         self.timezone    = self._init_timezone(abuse_group.settings_rep.timezone, **kwargs)
-        self.timing      = self._init_timing(abuse_group.settings_rep.timing, **kwargs)
+        self.timing      = self._init_timing(**kwargs)
         self.timing_cfg  = self._init_timing_cfg(abuse_group.settings_rep)
-        self.mute        = self._init_mute(abuse_group.settings_rep.mute, **kwargs)
         self.redirect    = self._init_redirect(abuse_group.settings_rep.redirect, **kwargs)
-        self.compress    = self._init_compress(abuse_group.settings_rep.compress, **kwargs)
-        self.max_size    = self._init_maxattachsize(abuse_group.settings_rep.max_attachment_size, **kwargs)
 
     def __repr__(self):
-        return 'ReportingSettings(group_name={};filters={};networks={};emails={};mode={};attachments={};template={};locale={};timezone={};timing={};timing_cfg={};mute={};redirect={};compress={};max_size={})'.format(
+        return 'ReportingSettings(group_name={};filters={};networks={};emails={};mode={};template={};locale={};timezone={};timing={};timing_cfg={};redirect={})'.format(
             self.group_name,
             pprint.pformat(self.filters, compact = True),
             pprint.pformat(self.networks, compact = True),
             pprint.pformat(self.emails, compact = True),
             pprint.pformat(self.mode, compact = True),
-            pprint.pformat(self.attachments, compact = True),
             pprint.pformat(self.template, compact = True),
             pprint.pformat(self.locale, compact = True),
             pprint.pformat(self.timezone, compact = True),
             pprint.pformat(self.timing, compact = True),
             pprint.pformat(self.timing_cfg, compact = True, width = 10000),
-            pprint.pformat(self.mute, compact = True),
-            pprint.pformat(self.redirect, compact = True),
-            pprint.pformat(self.compress, compact = True),
-            pprint.pformat(self.max_size, compact = True)
+            pprint.pformat(self.redirect, compact = True)
         )
 
     @staticmethod
-    def _init_emails(group_value, settings_emails):
-        if settings_emails:
-            return settings_emails
-        return [group_value]
+    def _init_emails(group_value, settings):
+        if settings.emails_low or settings.emails_medium or settings.emails_high or settings.emails_critical:
+            return (settings.emails_low, settings.emails_medium, settings.emails_high, settings.emails_critical)
+        return ([group_value], [], [], [])
 
     @staticmethod
     def _init_mode(group_value, **kwargs):
@@ -85,21 +77,9 @@ class ReportingSettings: # pylint: disable=locally-disabled,too-many-instance-at
         return mentat.const.DFLT_REPORTING_MODE
 
     @staticmethod
-    def _init_attachments(group_value, **kwargs):
-        if 'force_attachments' in kwargs and kwargs['force_attachments'] is not None:
-            if kwargs['force_attachments'] not in mentat.const.REPORTING_ATTACHS:
-                raise ValueError("Invalid value '{}' for reporting attachments.".format(kwargs['force_attachments']))
-            return str(kwargs['force_attachments'])
-        if group_value is not None:
-            return group_value
-        return mentat.const.DFLT_REPORTING_ATTACHMENTS
-
-    @staticmethod
-    def _init_template(group_value, **kwargs):
+    def _init_template(**kwargs):
         if 'force_template' in kwargs and kwargs['force_template'] is not None:
             return str(kwargs['force_template'])
-        if group_value is not None:
-            return group_value
         return mentat.const.DFLT_REPORTING_TEMPLATE
 
     @staticmethod
@@ -120,14 +100,6 @@ class ReportingSettings: # pylint: disable=locally-disabled,too-many-instance-at
             return group_value
         return mentat.const.DFLT_REPORTING_TIMEZONE
 
-    @staticmethod
-    def _init_mute(group_value, **kwargs):
-        if 'force_mute' in kwargs and kwargs['force_mute'] is not None:
-            return bool(kwargs['force_mute'])
-        if group_value is not None:
-            return group_value
-        return mentat.const.DFLT_REPORTING_MUTE
-
     @staticmethod
     def _init_redirect(group_value, **kwargs):
         if 'force_redirect' in kwargs and kwargs['force_redirect'] is not None:
@@ -137,124 +109,58 @@ class ReportingSettings: # pylint: disable=locally-disabled,too-many-instance-at
         return mentat.const.DFLT_REPORTING_REDIRECT
 
     @staticmethod
-    def _init_compress(group_value, **kwargs):
-        if 'force_compress' in kwargs and kwargs['force_compress'] is not None:
-            return bool(kwargs['force_compress'])
-        if group_value is not None:
-            return group_value
-        return mentat.const.DFLT_REPORTING_COMPRESS
-
-    @staticmethod
-    def _init_timing(group_value, **kwargs):
+    def _init_timing(**kwargs):
         if 'force_timing' in kwargs and kwargs['force_timing'] is not None:
             if kwargs['force_timing'] not in mentat.const.REPORTING_TIMINGS:
                 raise ValueError("Invalid value '{}' for reporting timing.".format(kwargs['force_timing']))
             return str(kwargs['force_timing'])
-        if group_value is not None:
-            return group_value
         return mentat.const.DFLT_REPORTING_TIMING
 
-    @staticmethod
-    def _init_maxattachsize(group_value, **kwargs):
-        if 'force_maxattachsize' in kwargs and kwargs['force_maxattachsize'] is not None:
-            return int(kwargs['force_maxattachsize'])
-        if group_value is not None:
-            return group_value
-        return mentat.const.DFLT_REPORTING_MAXATTACHSIZE
-
     @staticmethod
     def _init_timing_cfg(settings_rep):
-        if settings_rep.timing == mentat.const.REPORTING_TIMING_DEFAULT:
-            return {
-                mentat.const.EVENT_SEVERITY_LOW: {
-                    'per': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_PER]
-                    ),
-                    'thr': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_THR]
-                    ),
-                    'rel': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_REL]
-                    )
-                },
-                mentat.const.EVENT_SEVERITY_MEDIUM: {
-                    'per': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_PER]
-                    ),
-                    'thr': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_THR]
-                    ),
-                    'rel': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_REL]
-                    )
-                },
-                mentat.const.EVENT_SEVERITY_HIGH: {
-                    'per': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_PER]
-                    ),
-                    'thr': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_THR]
-                    ),
-                    'rel': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_REL]
-                    )
-                },
-                mentat.const.EVENT_SEVERITY_CRITICAL: {
-                    'per': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_PER]
-                    ),
-                    'thr': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_THR]
-                    ),
-                    'rel': datetime.timedelta(
-                        seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_REL]
-                    )
-                }
-            }
-
         return {
             mentat.const.EVENT_SEVERITY_LOW: {
                 'per': datetime.timedelta(
-                    seconds = settings_rep.timing_per_lo or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_PER]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_PER]
                 ),
                 'thr': datetime.timedelta(
-                    seconds = settings_rep.timing_thr_lo or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_THR]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_THR]
                 ),
                 'rel': datetime.timedelta(
-                    seconds = settings_rep.timing_rel_lo or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_REL]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_LOW_REL]
                 )
             },
             mentat.const.EVENT_SEVERITY_MEDIUM: {
                 'per': datetime.timedelta(
-                    seconds = settings_rep.timing_per_md or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_PER]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_PER]
                 ),
                 'thr': datetime.timedelta(
-                    seconds = settings_rep.timing_thr_md or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_THR]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_THR]
                 ),
                 'rel': datetime.timedelta(
-                    seconds = settings_rep.timing_rel_md or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_REL]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_MEDIUM_REL]
                 )
             },
             mentat.const.EVENT_SEVERITY_HIGH: {
                 'per': datetime.timedelta(
-                    seconds = settings_rep.timing_per_hi or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_PER]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_PER]
                 ),
                 'thr': datetime.timedelta(
-                    seconds = settings_rep.timing_thr_hi or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_THR]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_THR]
                 ),
                 'rel': datetime.timedelta(
-                    seconds = settings_rep.timing_rel_hi or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_REL]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_HIGH_REL]
                 )
             },
             mentat.const.EVENT_SEVERITY_CRITICAL: {
                 'per': datetime.timedelta(
-                    seconds = settings_rep.timing_per_cr or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_PER]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_PER]
                 ),
                 'thr': datetime.timedelta(
-                    seconds = settings_rep.timing_thr_cr or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_THR]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_THR]
                 ),
                 'rel': datetime.timedelta(
-                    seconds = settings_rep.timing_rel_cr or mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_REL]
+                    seconds = mentat.const.REPORTING_INTERVALS[mentat.const.REPORTING_TIMING_DEFAULT_CRITICAL_REL]
                 )
             }
         }
@@ -295,7 +201,7 @@ class ReportingSettings: # pylint: disable=locally-disabled,too-many-instance-at
         for net in self.networks:
             result.append(mentat.datatype.internal.t_network_record({
                 'network': net.network,
-                'resolved_abuses': [self.group_name]
+                'abuse_group': self.group_name
             }))
         return result
 
@@ -411,7 +317,7 @@ class ThresholdingCache:
         :return: Cache key as strings.
         :rtype: str
         """
-        event_class = jpath_value(event, '_CESNET.EventClass')
+        event_class = jpath_value(event, '_Mentat.EventClass') or jpath_value(event, '_CESNET.EventClass')
         if not event_class:
             event_class = '/'.join(jpath_values(event, 'Category'))
         return '+++'.join((event_class, str(source)))
