@@ -92,7 +92,7 @@ IDEA_INTO = mentat.idea.internal.Idea({
             'AggrWin': '00:05:00'
         }
     ],
-    '_CESNET' : {
+    '_Mentat' : {
         'StorageTime' : '2017-04-05T10:21:39Z',
         'EventTemplate' : 'sserv-012',
         'ResolvedAbuses' : [
