@@ -315,7 +315,7 @@ def _bq_where(parameters):
 
         if parameters.get('host_ports', None):
             chunks.append(psycopg2.sql.SQL('({} && %s OR {} && %s)').format(psycopg2.sql.Identifier('source_port'), psycopg2.sql.Identifier('target_port')))
-            params.extend([parameters['host_ports'], [int(x) for x in parameters['host_ports']]])
+            params.extend([[int(x) for x in parameters['host_ports']], [int(x) for x in parameters['host_ports']]])
         else:
             if parameters.get('source_ports', None):
                 chunks.append(psycopg2.sql.SQL('{} && %s').format(psycopg2.sql.Identifier('source_port')))
